@@ -1,7 +1,4 @@
-#ifndef lint
-static char rcsid[] = "@(#$Id: rclconfig.cpp,v 1.62 2008-10-08 16:15:22 dockes Exp $ (C) 2004 J.F.Dockes";
-#endif
-/*
+/* Copyright (C) 2004 J.F.Dockes 
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
  *   the Free Software Foundation; either version 2 of the License, or
@@ -59,7 +56,11 @@ using namespace std;
 
 bool ParamStale::needrecompute()
 {
+    LOGDEB2(("ParamStale:: needrecompute. parent gen %d mine %d\n", 
+	     parent->m_keydirgen, savedkeydirgen));
     if (parent->m_keydirgen != savedkeydirgen) {
+	LOGDEB2(("ParamState:: needrecompute. conffile %p\n", conffile));
+
         savedkeydirgen = parent->m_keydirgen;
         string newvalue;
         if (!conffile)
@@ -67,6 +68,8 @@ bool ParamStale::needrecompute()
         conffile->get(paramname, newvalue, parent->m_keydir);
         if (newvalue.compare(savedvalue)) {
             savedvalue = newvalue;
+	    LOGDEB2(("ParamState:: needrecompute. return true newvalue [%s]\n",
+		     newvalue.c_str()));
             return true;
         }
     }
@@ -323,7 +326,12 @@ list<string> RclConfig::getTopdirs()
 // (only the locale).
 const string& RclConfig::getDefCharset(bool filename) 
 {
-    // This can't change once computed inside a process.
+    // This can't change once computed inside a process. It would be
+    // nicer to move this to a static class initializer to avoid
+    // possible threading issues but this doesn't work (tried) as
+    // things would not be ready. In practise we make sure that this
+    // is called from the main thread at once, by calling
+    // getDefCharset from recollinit
     static string localecharset; 
     if (localecharset.empty()) {
 	const char *cp;
@@ -437,7 +445,9 @@ typedef multiset<SfString, SuffCmp> SuffixStore;
 
 bool RclConfig::inStopSuffixes(const string& fni)
 {
-    if (m_stopsuffixes == 0 || m_stpsuffstate.needrecompute()) {
+    LOGDEB2(("RclConfig::inStopSuffixes(%s)\n", fni.c_str()));
+    // Beware: needrecompute() needs to be called always. 2nd test stays back.
+    if (m_stpsuffstate.needrecompute() || m_stopsuffixes == 0) {
 	// Need to initialize the suffixes
         delete STOPSUFFIXES;
 	if ((m_stopsuffixes = new SuffixStore) == 0) {
@@ -673,6 +683,17 @@ bool RclConfig::getFieldPrefix(const string& _fld, string &pfx)
     }
 }
 
+set<string> RclConfig::getIndexedFields()
+{
+    set<string> flds;
+    if (m_fields == 0)
+	return flds;
+
+    list<string> sl = m_fields->getNames("prefixes");
+    flds.insert(sl.begin(), sl.end());
+    return flds;
+}
+
 // Return specialisations of field name for search expansion 
 // (ie: author->[author, from])
 bool RclConfig::getFieldSpecialisations(const string& fld, 
