@@ -1,7 +1,4 @@
-#ifndef lint
-static char rcsid[] = "@(#$Id: rclinit.cpp,v 1.11 2007-12-13 06:58:21 dockes Exp $ (C) 2004 J.F.Dockes";
-#endif
-/*
+/* Copyright (C) 2004 J.F.Dockes
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
  *   the Free Software Foundation; either version 2 of the License, or
@@ -95,6 +92,10 @@ RclConfig *recollinit(RclInitFlags flags,
     // to utf8 for indexing.
     setlocale(LC_CTYPE, "");
 
+    // Make sure the locale charset is initialized (so that multiple
+    // threads don't try to do it at once).
+    config->getDefCharset();
+
     return config;
 }
 
