@@ -101,17 +101,27 @@ class RclExecM:
 
         # If we're given a file name, open it. 
         if len(params["filename:"]) != 0:
-            if not processor.openfile(params):
+            try:
+                if not processor.openfile(params):
+                    self.answer("", "", iserror = RclExecM.fileerror)
+                    return
+            except Exception, err:
+                self.em.rclog("processmessage: openfile raised: [%s]" % err)
                 self.answer("", "", iserror = RclExecM.fileerror)
                 return
-            
+
         # If we have an ipath, that's what we look for, else ask for next entry
         ipath = ""
         self.mimetype = ""
-        if params.has_key("ipath:") and len(params["ipath:"]):
-            ok, data, ipath, eof = processor.getipath(params)
-        else:
-            ok, data, ipath, eof = processor.getnext(params)
+        try:
+            if params.has_key("ipath:") and len(params["ipath:"]):
+                ok, data, ipath, eof = processor.getipath(params)
+            else:
+                ok, data, ipath, eof = processor.getnext(params)
+        except Exception, err:
+            self.answer("", "", eof, RclExecM.fileerror)
+            return
+
         #self.rclog("processmessage: ok %s eof %s ipath %s"%(ok, eof, ipath))
         if ok:
             self.answer(data, ipath, eof)
@@ -145,7 +155,8 @@ def main(proto, extract):
     else:
         # Got a file name parameter: TESTING without an execm parent
         # Loop on all entries or get specific ipath
-        if not extract.openfile({'filename:':sys.argv[1]}):
+        params = {'filename:':sys.argv[1]}
+        if not extract.openfile(params):
             print "Open error"
             sys.exit(1)
         ipath = ""
@@ -153,7 +164,8 @@ def main(proto, extract):
             ipath = sys.argv[2]
 
         if ipath != "":
-            ok, data, ipath, eof = extract.getipath({'ipath:':ipath})
+            params['ipath:'] = ipath
+            ok, data, ipath, eof = extract.getipath(params)
             if ok:
                 print "== Found entry for ipath %s (mimetype [%s]):" % \
                       (ipath, proto.mimetype)
@@ -165,13 +177,15 @@ def main(proto, extract):
 
         ecnt = 0   
         while 1:
-            ok, data, ipath, eof = extract.getnext("")
+            ok, data, ipath, eof = extract.getnext(params)
             if ok:
                 ecnt = ecnt + 1
-                print "== Entry %d ipath %s (mimetype [%s]:" % \
+                print "== Entry %d ipath %s (mimetype [%s]):" % \
                       (ecnt, ipath, proto.mimetype)
-#                print data
+                print data
                 print
+                if eof != RclExecM.noteof:
+                    break
             else:
                 print "Not ok, eof %d" % eof
                 break
