@@ -1,4 +1,4 @@
-/*
+/* Copyright (C) 2005 J.F.Dockes
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
  *   the Free Software Foundation; either version 2 of the License, or
@@ -14,9 +14,6 @@
  *   Free Software Foundation, Inc.,
  *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  */
-#ifndef lint
-static char rcsid[] = "@(#$Id: $ (C) 2005 J.F.Dockes";
-#endif
 #include "autoconfig.h"
 
 #include <unistd.h>
@@ -232,10 +229,9 @@ bool BeagleQueueIndexer::indexFromCache(const string& udi)
         FileInterner interner(data, m_config, m_tmpdir, 
                               FileInterner::FIF_doUseInputMimetype,
                               dotdoc.mimetype);
-        string ipath;
         FileInterner::Status fis;
         try {
-            fis = interner.internfile(doc, ipath);
+            fis = interner.internfile(doc);
         } catch (CancelExcept) {
             LOGERR(("BeagleQueueIndexer: interrupted\n"));
             return false;
@@ -437,10 +433,9 @@ BeagleQueueIndexer::processone(const string &path,
         FileInterner interner(path, stp, m_config, m_tmpdir, 
                               FileInterner::FIF_doUseInputMimetype,
                               &dotdoc.mimetype);
-        string ipath;
         FileInterner::Status fis;
         try {
-            fis = interner.internfile(doc, ipath);
+            fis = interner.internfile(doc);
         } catch (CancelExcept) {
             LOGERR(("BeagleQueueIndexer: interrupted\n"));
             goto out;
