@@ -1,7 +1,4 @@
-#ifndef lint
-static char rcsid[] = "@(#$Id: $ (C) 2009 J.F.Dockes";
-#endif
-/*
+/* Copyright (C) 2009 J.F.Dockes
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
  *   the Free Software Foundation; either version 2 of the License, or
@@ -66,7 +63,13 @@ using namespace std;
 #define deleteZ(X) {delete X;X = 0;}
 #endif
 
+FsIndexer::FsIndexer(RclConfig *cnf, Rcl::Db *db, DbIxStatusUpdater *updfunc) 
+    : m_config(cnf), m_db(db), m_updater(updfunc), m_missing(new FIMissingStore)
+{
+    m_havelocalfields = m_config->hasNameAnywhere("localfields");
+}
 FsIndexer::~FsIndexer() {
+    delete m_missing;
 }
 
 bool FsIndexer::init()
@@ -124,7 +127,7 @@ bool FsIndexer::index()
     }
 
     string missing;
-    FileInterner::getMissingDescription(missing);
+    FileInterner::getMissingDescription(m_missing, missing);
     if (!missing.empty()) {
 	LOGINFO(("FsIndexer::index missing helper program(s):\n%s\n", 
 		 missing.c_str()));
@@ -362,6 +365,7 @@ FsIndexer::processone(const std::string &fn, const struct stat *stp,
         // indexallfilenames is not set
         return FsTreeWalker::FtwOk;
     }
+    interner.setMissingStore(m_missing);
 
     // File name transcoded to utf8 for indexing. 
     string charset = m_config->getDefCharset(true);
@@ -391,9 +395,8 @@ FsIndexer::processone(const std::string &fn, const struct stat *stp,
     bool hadNullIpath = false;
     while (fis == FileInterner::FIAgain) {
 	doc.erase();
-	string ipath;
         try {
-            fis = interner.internfile(doc, ipath);
+            fis = interner.internfile(doc);
         } catch (CancelExcept) {
             LOGERR(("fsIndexer::processone: interrupted\n"));
             return FsTreeWalker::FtwStop;
@@ -404,10 +407,8 @@ FsIndexer::processone(const std::string &fn, const struct stat *stp,
         // be retried every time.
 
 	// Internal access path for multi-document files
-	if (ipath.empty())
+	if (doc.ipath.empty())
 	    hadNullIpath = true;
-	else
-	    doc.ipath = ipath;
 
 	// Set file name, mod time and url if not done by filter
 	if (doc.fmtime.empty())
@@ -441,8 +442,8 @@ FsIndexer::processone(const std::string &fn, const struct stat *stp,
 	// Add document to database. If there is an ipath, add it as a children
 	// of the file document.
 	string udi;
-	make_udi(fn, ipath, udi);
-	if (!m_db->addOrUpdate(udi, ipath.empty() ? "" : parent_udi, doc)) 
+	make_udi(fn, doc.ipath, udi);
+	if (!m_db->addOrUpdate(udi, doc.ipath.empty() ? "" : parent_udi, doc)) 
 	    return FsTreeWalker::FtwError;
 
 	// Tell what we are doing and check for interrupt request
@@ -451,8 +452,8 @@ FsIndexer::processone(const std::string &fn, const struct stat *stp,
             if (m_updater->status.dbtotdocs < m_updater->status.docsdone)
                 m_updater->status.dbtotdocs = m_updater->status.docsdone;
             m_updater->status.fn = fn;
-            if (!ipath.empty())
-                m_updater->status.fn += "|" + ipath;
+            if (!doc.ipath.empty())
+                m_updater->status.fn += "|" + doc.ipath;
             if (!m_updater->update()) {
                 return FsTreeWalker::FtwStop;
             }
