@@ -1,4 +1,4 @@
-/*
+/* Copyright (C) 2009 J.F.Dockes
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
  *   the Free Software Foundation; either version 2 of the License, or
@@ -16,7 +16,6 @@
  */
 #ifndef _fsindexer_h_included_
 #define _fsindexer_h_included_
-/* @(#$Id: $  (C) 2009 J.F.Dockes */
 
 #include <list>
 #ifndef NO_NAMESPACES
@@ -27,6 +26,7 @@ using std::list;
 #include "rcldb.h"
 
 class DbIxStatusUpdater;
+class FIMissingStore;
 
 /** Index selected parts of the file system
  
@@ -46,12 +46,7 @@ class FsIndexer : public FsTreeWalkerCB {
      * @param cnf Configuration data
      * @param updfunc Status updater callback
      */
-    FsIndexer(RclConfig *cnf, Rcl::Db *db, DbIxStatusUpdater *updfunc = 0) 
-	: m_config(cnf), m_db(db), m_updater(updfunc)
-    {
-        m_havelocalfields = m_config->hasNameAnywhere("localfields");
-    }
-	
+    FsIndexer(RclConfig *cnf, Rcl::Db *db, DbIxStatusUpdater *updfunc = 0);
     virtual ~FsIndexer();
 
     /** 
@@ -80,6 +75,7 @@ class FsIndexer : public FsTreeWalkerCB {
     string       m_reason;
     DbIxStatusUpdater *m_updater;
     list<string> m_tdl;
+    FIMissingStore *m_missing;
 
     // The configuration can set attribute fields to be inherited by
     // all files in a file system area. Ie: set "rclaptg = thunderbird"
