@@ -1,7 +1,4 @@
-#ifndef lint
-static char rcsid[] = "@(#$Id: indexer.cpp,v 1.71 2008-12-17 08:01:40 dockes Exp $ (C) 2004 J.F.Dockes";
-#endif
-/*
+/* Copyright (C) 2004 J.F.Dockes
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
  *   the Free Software Foundation; either version 2 of the License, or
@@ -81,22 +78,27 @@ bool ConfIndexer::index(bool resetbefore, ixType typestorun)
     if (typestorun == IxTAll) {
         // Get rid of all database entries that don't exist in the
         // filesystem anymore. Only if all *configured* indexers ran.
-        if (m_updater)
-            m_updater->update(DbIxStatus::DBIXS_PURGE, string());
+        if (m_updater && !m_updater->update(DbIxStatus::DBIXS_PURGE, string()))
+	    return false;
         m_db.purge();
     }
 
+    // The close would be done in our destructor, but we want status
+    // here. Makes no sense to check for cancel, we'll have to close
+    // anyway
     if (m_updater)
 	m_updater->update(DbIxStatus::DBIXS_CLOSING, string());
-
-    // The close would be done in our destructor, but we want status here
     if (!m_db.close()) {
 	LOGERR(("ConfIndexer::index: error closing database in %s\n", 
 		m_config->getDbDir().c_str()));
 	return false;
     }
 
+    if (m_updater && !m_updater->update(DbIxStatus::DBIXS_CLOSING, string()))
+	return false;
     createStemmingDatabases();
+    if (m_updater && !m_updater->update(DbIxStatus::DBIXS_CLOSING, string()))
+	return false;
     createAspellDict();
     clearMimeHandlerCache();
     return true;
@@ -208,8 +210,8 @@ bool ConfIndexer::createStemmingDatabases()
 		m_db.deleteStemDb(*it);
 	}
 	for (it = langs.begin(); it != langs.end(); it++) {
-	    if (m_updater)
-		m_updater->update(DbIxStatus::DBIXS_STEMDB, *it);
+	    if (m_updater && !m_updater->update(DbIxStatus::DBIXS_STEMDB, *it))
+		return false;
 	    m_db.createStemDb(*it);
 	}
     }
