@@ -1,7 +1,4 @@
-#ifndef lint
-static char rcsid[] = "@(#$Id: internfile.cpp,v 1.46 2008-10-10 08:04:54 dockes Exp $ (C) 2004 J.F.Dockes";
-#endif
-/*
+/* Copyright (C) 2004 J.F.Dockes 
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
  *   the Free Software Foundation; either version 2 of the License, or
@@ -48,18 +45,37 @@ using namespace std;
 #include "beaglequeuecache.h"
 #include "cancelcheck.h"
 #include "copyfile.h"
+#include "ptmutex.h"
 
 #ifdef RCL_USE_XATTR
 #include "pxattr.h"
 #endif // RCL_USE_XATTR
 
-// The internal path element separator. This can't be the same as the rcldb 
-// file to ipath separator : "|"
-static const string isep(":");
 static const string stxtplain("text/plain");
 
-set<string> FileInterner::o_missingExternal;
-map<string, set<string> >  FileInterner::o_typesForMissing;
+// The internal path element separator. This can't be the same as the rcldb 
+// file to ipath separator : "|"
+// We replace it with a control char if it comes out of a filter (ie:
+// rclzip or rclchm can do this). If you want the SOH control char
+// inside an ipath, you're out of luck (and a bit weird).
+static const string isep(":");
+static const char colon_repl = '\x01';
+static string colon_hide(const string& in)
+{
+    string out;
+    for (string::const_iterator it = in.begin(); it != in.end(); it++) {
+	out += *it == ':' ? colon_repl : *it;
+    }
+    return out;
+}
+static string colon_restore(const string& in)
+{
+    string out;
+    for (string::const_iterator it = in.begin(); it != in.end(); it++) {
+	out += *it == colon_repl ? ':' : *it;
+    }
+    return out;
+}
 
 #ifdef RCL_USE_XATTR
 void FileInterner::reapXAttrs(const string& path)
@@ -95,7 +111,8 @@ bool FileInterner::getEnclosing(const string &url, const string &ipath,
     eurl = url;
     eipath = ipath;
     string::size_type colon;
-    LOGDEB(("FileInterner::getEnclosing(): [%s]\n", eipath.c_str()));
+    LOGDEB(("FileInterner::getEnclosing(): url [%s] ipath [%s]\n", 
+	    url.c_str(), eipath.c_str()));
     if (eipath.empty())
 	return false;
     if ((colon =  eipath.find_last_of(isep)) != string::npos) {
@@ -173,7 +190,7 @@ void FileInterner::tmpcleanup()
 FileInterner::FileInterner(const string &f, const struct stat *stp,
 			   RclConfig *cnf, 
 			   TempDir& td, int flags, const string *imime)
-    : m_tdir(td), m_ok(false)
+    : m_tdir(td), m_ok(false), m_missingdatap(0)
 {
     initcommon(cnf, flags);
     init(f, stp, cnf, flags, imime);
@@ -285,7 +302,7 @@ void FileInterner::init(const string &f, const struct stat *stp, RclConfig *cnf,
 // Setup from memory data (ie: out of the web cache). imime needs to be set.
 FileInterner::FileInterner(const string &data, RclConfig *cnf, 
                            TempDir& td, int flags, const string& imime)
-    : m_tdir(td), m_ok(false)
+    : m_tdir(td), m_ok(false), m_missingdatap(0)
 {
     initcommon(cnf, flags);
     init(data, cnf, flags, imime);
@@ -347,9 +364,13 @@ void FileInterner::initcommon(RclConfig *cnf, int flags)
     m_targetMType = stxtplain;
 }
 
+// We used a single beagle cache object to access beagle data. We protect it 
+// against multiple thread access.
+static PTMutexInit o_lock;
+
 FileInterner::FileInterner(const Rcl::Doc& idoc, RclConfig *cnf, 
                            TempDir& td, int flags)
-    : m_tdir(td), m_ok(false)
+    : m_tdir(td), m_ok(false), m_missingdatap(0)
 {
     LOGDEB(("FileInterner::FileInterner(idoc)\n"));
     initcommon(cnf, flags);
@@ -386,10 +407,6 @@ FileInterner::FileInterner(const Rcl::Doc& idoc, RclConfig *cnf,
         }
         init(fn, &st, cnf, flags, &idoc.mimetype);
     } else if (!backend.compare("BGL")) {
-        // Retrieve from our webcache (beagle data). The beagler
-        // object is created at the first call of this routine and
-        // deleted when the program exits.
-        static BeagleQueueCache beagler(cnf);
         string data;
         Rcl::Doc dotdoc;
         map<string,string>::const_iterator it = 
@@ -399,11 +416,19 @@ FileInterner::FileInterner(const Rcl::Doc& idoc, RclConfig *cnf,
             return;
         }
         string udi = it->second;
-        if (!beagler.getFromCache(udi, dotdoc, data)) {
-            LOGINFO(("FileInterner:: failed fetch from Beagle cache for [%s]\n",
-                     udi.c_str()));
-            return;
-        }
+
+	{
+	    PTMutexLocker locker(o_lock);
+	    // Retrieve from our webcache (beagle data). The beagler
+	    // object is created at the first call of this routine and
+	    // deleted when the program exits.
+	    static BeagleQueueCache beagler(cnf);
+	    if (!beagler.getFromCache(udi, dotdoc, data)) {
+		LOGINFO(("FileInterner:: failed fetch from Beagle cache for [%s]\n",
+			 udi.c_str()));
+		return;
+	    }
+	}
         if (dotdoc.mimetype.compare(idoc.mimetype)) {
             LOGINFO(("FileInterner:: udi [%s], mimetp mismatch: in: [%s], bgl "
                      "[%s]\n", idoc.mimetype.c_str(), dotdoc.mimetype.c_str()));
@@ -466,7 +491,7 @@ bool FileInterner::dataToTempFile(const string& dt, const string& mt,
 // accumulate helper name if it is
 void FileInterner::checkExternalMissing(const string& msg, const string& mt)
 {
-    if (msg.find("RECFILTERROR") == 0) {
+    if (m_missingdatap && msg.find("RECFILTERROR") == 0) {
 	list<string> lerr;
 	stringToStrings(msg, lerr);
 	if (lerr.size() > 2) {
@@ -476,28 +501,33 @@ void FileInterner::checkExternalMissing(const string& msg, const string& mt)
 		lerr.erase(it++);
 		string s;
 		stringsToString(lerr, s);
-		o_missingExternal.insert(s);
-		o_typesForMissing[s].insert(mt);
+		m_missingdatap->m_missingExternal.insert(s);
+		m_missingdatap->m_typesForMissing[s].insert(mt);
 	    }
 	}		    
     }
 }
 
-void FileInterner::getMissingExternal(string& out) 
+void FileInterner::getMissingExternal(FIMissingStore *st, string& out) 
 {
-    stringsToString(o_missingExternal, out);
+    if (st)
+	stringsToString(st->m_missingExternal, out);
 }
 
-void FileInterner::getMissingDescription(string& out)
+void FileInterner::getMissingDescription(FIMissingStore *st, string& out)
 {
+    if (st == 0)
+	return;
+
     out.erase();
 
-    for (set<string>::const_iterator it = o_missingExternal.begin();
-	     it != o_missingExternal.end(); it++) {
+    for (set<string>::const_iterator it = 
+	     st->m_missingExternal.begin();
+	 it != st->m_missingExternal.end(); it++) {
 	out += *it;
 	map<string, set<string> >::const_iterator it2;
-	it2 = o_typesForMissing.find(*it);
-	if (it2 != o_typesForMissing.end()) {
+	it2 = st->m_typesForMissing.find(*it);
+	if (it2 != st->m_typesForMissing.end()) {
 	    out += " (";
 	    set<string>::const_iterator it3;
 	    for (it3 = it2->second.begin(); 
@@ -578,6 +608,7 @@ bool FileInterner::dijontorcl(Rcl::Doc& doc)
 // which has them.
 void FileInterner::collectIpathAndMT(Rcl::Doc& doc, string& ipath) const
 {
+    LOGDEB2(("FileInterner::collectIpathAndMT\n"));
     bool hasipath = false;
 
 #ifdef RCL_USE_XATTR
@@ -603,7 +634,7 @@ void FileInterner::collectIpathAndMT(Rcl::Doc& doc, string& ipath) const
 		getKeyValue(docdata, keymt, doc.mimetype);
 		getKeyValue(docdata, keyfn, doc.utf8fn);
 	    }
-	    ipath += ipathel + isep;
+	    ipath += colon_hide(ipathel) + isep;
 	} else {
 	    ipath += isep;
 	}
@@ -731,7 +762,7 @@ void FileInterner::processNextDocError(Rcl::Doc &doc, string& ipath)
 	    ipath.c_str(), doc.mimetype.c_str(), m_reason.c_str()));
 }
 
-FileInterner::Status FileInterner::internfile(Rcl::Doc& doc, string& ipath)
+FileInterner::Status FileInterner::internfile(Rcl::Doc& doc, const string& ipath)
 {
     LOGDEB(("FileInterner::internfile. ipath [%s]\n", ipath.c_str()));
     if (m_handlers.size() < 1) {
@@ -745,11 +776,15 @@ FileInterner::Status FileInterner::internfile(Rcl::Doc& doc, string& ipath)
     // over the last significant one are ""
     // We set the ipath for the first handler here, others are set
     // when they're pushed on the stack
-    vector<string> vipath(MAXHANDLERS);
+    vector<string> vipath;
     int vipathidx = 0;
     if (!ipath.empty()) {
 	vector<string> lipath;
 	stringToTokens(ipath, lipath, isep, true);
+	for (vector<string>::iterator it = lipath.begin();
+	     it != lipath.end(); it++) {
+	    *it = colon_restore(*it);
+	}
 	vipath.insert(vipath.begin(), lipath.begin(), lipath.end());
 	if (!m_handlers.back()->skip_to_document(vipath[m_handlers.size()-1])){
 	    LOGERR(("FileInterner::internfile: can't skip\n"));
@@ -791,7 +826,8 @@ FileInterner::Status FileInterner::internfile(Rcl::Doc& doc, string& ipath)
 	// might be ie an error while decoding an attachment, but we
 	// still want to process the rest of the mbox! For preview: fatal.
 	if (!m_handlers.back()->next_document()) {
-	    processNextDocError(doc, ipath);
+	    string oipath;
+	    processNextDocError(doc, oipath);
 	    if (m_forPreview) {
                 m_reason += "Requested document does not exist. ";
                 m_reason += m_handlers.back()->get_error();
@@ -806,22 +842,36 @@ FileInterner::Status FileInterner::internfile(Rcl::Doc& doc, string& ipath)
 	// handler to stack.
 	switch (addHandler()) {
 	case ADD_OK: // Just go through: handler has been stacked, use it
+	    LOGDEB2(("addHandler returned OK\n"));
 	    break; 
 	case ADD_CONTINUE: 
 	    // forget this doc and retrieve next from current handler
 	    // (ipath stays same)
+	    LOGDEB2(("addHandler returned CONTINUE\n"));
 	    continue;
 	case ADD_BREAK: 
 	    // Stop looping: doc type ok, need complete its processing
 	    // and return it
+	    LOGDEB2(("addHandler returned BREAK\n"));
 	    goto breakloop; // when you have to you have to
-	case ADD_ERROR: return FIError;
+	case ADD_ERROR: 
+	    LOGDEB2(("addHandler returned ERROR\n"));
+	    return FIError;
 	}
 
-	if (!ipath.empty() &&
-	    !m_handlers.back()->skip_to_document(vipath[m_handlers.size()-1])){
-	    LOGERR(("FileInterner::internfile: can't skip\n"));
-	    return FIError;
+	// If we have an ipath, meaning that we are seeking a specific
+	// document (ie: previewing a search result), we may have to
+	// seek to the correct entry of a compound doc (ie: archive or
+	// mail). When we are out of ipath entries, we stop seeking,
+	// the handlers stack may still grow for translation (ie: if
+	// the target doc is msword, we'll still stack the
+	// word-to-text translator).
+	if (!ipath.empty()) {
+	    if (m_handlers.size() <= vipath.size() &&
+		!m_handlers.back()->skip_to_document(vipath[m_handlers.size()-1])) {
+		LOGERR(("FileInterner::internfile: can't skip\n"));
+		return FIError;
+	    }
 	}
     }
  breakloop:
@@ -831,16 +881,16 @@ FileInterner::Status FileInterner::internfile(Rcl::Doc& doc, string& ipath)
     }
 
     // If indexing compute ipath and significant mimetype.  ipath is
-    // returned through the parameter not doc.ipath We also retrieve
-    // some metadata fields from the ancesters (like date or
-    // author). This is useful for email attachments. The values will
-    // be replaced by those internal to the document (by dijontorcl())
-    // if any, so the order of calls is important.
-    if (!m_forPreview)
-	collectIpathAndMT(doc, ipath);
-    else
+    // returned through doc.ipath. We also retrieve some metadata
+    // fields from the ancesters (like date or author). This is useful
+    // for email attachments. The values will be replaced by those
+    // internal to the document (by dijontorcl()) if any, so the order
+    // of calls is important.
+    if (!m_forPreview) {
+	collectIpathAndMT(doc, doc.ipath);
+    } else {
 	doc.mimetype = m_reachedMType;
-
+    }
     // Keep this AFTER collectIpathAndMT
     dijontorcl(doc);
 
@@ -891,8 +941,7 @@ bool FileInterner::idocToFile(TempFile& otemp, const string& tofile,
     FileInterner interner(idoc, cnf, tmpdir, FIF_forPreview);
     interner.setTargetMType(idoc.mimetype);
     Rcl::Doc doc;
-    string mipath = idoc.ipath;
-    Status ret = interner.internfile(doc, mipath);
+    Status ret = interner.internfile(doc, idoc.ipath);
     if (ret == FileInterner::FIError) {
 	LOGERR(("FileInterner::idocToFile: internfile() failed\n"));
 	return false;
