@@ -1,7 +1,4 @@
-#ifndef lint
-static char rcsid[] = "@(#$Id: mh_exec.cpp,v 1.14 2008-10-09 09:19:37 dockes Exp $ (C) 2005 J.F.Dockes";
-#endif
-/*
+/* Copyright (C) 2005 J.F.Dockes 
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
  *   the Free Software Foundation; either version 2 of the License, or
@@ -59,6 +56,13 @@ public:
 };
 
 
+bool MimeHandlerExec::skip_to_document(const string& ipath) 
+{
+    LOGDEB(("MimeHandlerExec:skip_to_document: [%s]\n", ipath.c_str()));
+    m_ipath = ipath;
+    return true;
+}
+
 // Execute an external program to translate a file from its native
 // format to text or html.
 bool MimeHandlerExec::next_document()
