@@ -1,7 +1,4 @@
-#ifndef lint
-static char rcsid[] = "@(#$Id: mh_exec.cpp,v 1.14 2008-10-09 09:19:37 dockes Exp $ (C) 2005 J.F.Dockes";
-#endif
-/*
+/* Copyright (C) 2005 J.F.Dockes 
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
  *   the Free Software Foundation; either version 2 of the License, or
@@ -167,6 +164,8 @@ bool MimeHandlerExecMultiple::next_document()
         obuf << "Filename: " << 0 << "\n";
     }
     if (m_ipath.length()) {
+	LOGDEB(("next_doc: sending len %d val [%s]\n", m_ipath.length(),
+		m_ipath.c_str()));
         obuf << "Ipath: " << m_ipath.length() << "\n" << m_ipath;
     }
     if (!m_dfltInputCharset.empty()) {
@@ -215,7 +214,7 @@ bool MimeHandlerExecMultiple::next_document()
             LOGDEB(("MHExecMultiple: got ipath [%s]\n", data.c_str()));
         } else if (!stringlowercmp("charset:", name)) {
             charset = data;
-            LOGDEB(("MHExecMultiple: got ipath [%s]\n", data.c_str()));
+            LOGDEB(("MHExecMultiple: got charset [%s]\n", data.c_str()));
         } else if (!stringlowercmp("mimetype:", name)) {
             mtype = data;
             LOGDEB(("MHExecMultiple: got mimetype [%s]\n", data.c_str()));
@@ -251,6 +250,8 @@ bool MimeHandlerExecMultiple::next_document()
     if (!ipath.empty()) {
         m_metaData["ipath"] = ipath;
         if (mtype.empty()) {
+	    LOGDEB0(("MHExecMultiple: no mime type from filter, "
+		    "using ipath for a guess\n"));
             mtype = mimetype(ipath, 0, m_config, false);
             if (mtype.empty()) {
                 // mimetype() won't call idFile when there is no file. Do it
@@ -296,5 +297,9 @@ bool MimeHandlerExecMultiple::next_document()
     if (eofnext_received)
         m_havedoc = false;
 
+    LOGDEB0(("MHExecMultiple: returning %d bytes of content,"
+	    " mtype [%s] charset [%s]\n", 
+	    m_metaData["content"].size(), m_metaData["mimetype"].c_str(),
+	    m_metaData["charset"].c_str()));
     return true;
 }
