@@ -1,7 +1,4 @@
-#ifndef lint
-static char rcsid[] = "@(#$Id: mh_mbox.cpp,v 1.5 2008-10-04 14:26:59 dockes Exp $ (C) 2005 J.F.Dockes";
-#endif
-/*
+/* Copyright (C) 2005 J.F.Dockes
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
  *   the Free Software Foundation; either version 2 of the License, or
@@ -40,6 +37,7 @@ static char rcsid[] = "@(#$Id: mh_mbox.cpp,v 1.5 2008-10-04 14:26:59 dockes Exp
 #include "rclconfig.h"
 #include "md5.h"
 #include "conftree.h"
+#include "ptmutex.h"
 
 using namespace std;
 class FpKeeper { 
@@ -55,6 +53,7 @@ public:
 private: FILE **m_fpp;
 };
 
+static PTMutexInit o_mutex;
 
 /**
  * Handles a cache for message numbers to offset translations. Permits direct
@@ -87,6 +86,7 @@ public:
             LOGDEB0(("MboxCache::get_offsets: init failed\n"));
             return -1;
         }
+	PTMutexLocker locker(o_mutex);
         string fn = makefilename(udi);
         FILE *fp = 0;
         if ((fp = fopen(fn.c_str(), "r")) == 0) {
@@ -133,6 +133,7 @@ public:
             return;
         if (fsize < m_minfsize)
             return;
+	PTMutexLocker locker(o_mutex);
         string fn = makefilename(udi);
         FILE *fp;
         if ((fp = fopen(fn.c_str(), "w")) == 0) {
@@ -162,6 +163,7 @@ public:
 
     // Check state, possibly initialize
     bool ok(RclConfig *config) {
+	PTMutexLocker locker(o_mutex);
         if (m_minfsize == -1)
             return false;
         if (!m_ok) {
@@ -221,7 +223,9 @@ private:
 };
 
 const size_t MboxCache::o_b1size = 1024;
+
 static class MboxCache mcache;
+
 static const string keyquirks("mhmboxquirks");
 
 MimeHandlerMbox::~MimeHandlerMbox()
@@ -392,6 +396,7 @@ bool MimeHandlerMbox::next_document()
     // avoid rereading the whole thing in this case. But I'm not sure
     // we're ever used in this way (multiple retrieves on same
     // object).  So:
+    bool storeoffsets = true;
     if (mtarg > 0) {
         mbhoff_type off;
         line_type line;
@@ -407,6 +412,7 @@ bool MimeHandlerMbox::next_document()
                 LOGDEB0(("MimeHandlerMbox: Cache: From_ Ok\n"));
                 fseeko(fp, (off_t)off, SEEK_SET);
                 m_msgnum = mtarg -1;
+		storeoffsets = false;
         } else {
             fseek(fp, 0, SEEK_SET);
             m_msgnum = 0;
@@ -447,7 +453,8 @@ bool MimeHandlerMbox::next_document()
 		     !regexec(&minifromregex, line, 0, 0, 0)) ) {
 		    LOGDEB1(("MimeHandlerMbox: msgnum %d, "
 		     "From_ at line %d: [%s]\n", m_msgnum, m_lineno, line));
-		    m_offsets.push_back(message_end);
+		    if (storeoffsets)
+			m_offsets.push_back(message_end);
 		    m_msgnum++;
 		    if ((mtarg <= 0 && m_msgnum > 1) || 
 			(mtarg > 0 && m_msgnum > mtarg)) {
@@ -480,7 +487,7 @@ bool MimeHandlerMbox::next_document()
     if (iseof) {
 	LOGDEB2(("MimeHandlerMbox::next: eof hit\n"));
 	m_havedoc = false;
-	if (!m_udi.empty()) {
+	if (!m_udi.empty() && storeoffsets) {
 	    mcache.put_offsets(m_config, m_udi, m_fsize, m_offsets);
 	}
     }
