@@ -1,7 +1,6 @@
-#ifndef lint
-static char rcsid[] = "@(#$Id: mimehandler.cpp,v 1.25 2008-10-09 09:19:37 dockes Exp $ (C) 2004 J.F.Dockes";
-#endif
 /*
+ *   Copyright 2004 J.F.Dockes
+ *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
  *   the Free Software Foundation; either version 2 of the License, or
@@ -37,6 +36,7 @@ using namespace std;
 #include "mh_mbox.h"
 #include "mh_text.h"
 #include "mh_unknown.h"
+#include "ptmutex.h"
 
 // Performance help: we use a pool of already known and created
 // handlers. There can be several instances for a given mime type
@@ -45,9 +45,10 @@ using namespace std;
 //
 // FIXME: this is not compatible with multiple threads and a potential
 // problem in the recoll gui (indexing thread + preview request). A
-// simple lock would be enough as handlers are removed from the cache
+// simple lock should be enough as handlers are removed from the cache
 // while in use and multiple copies are allowed
 static multimap<string, Dijon::Filter*>  o_handlers;
+static PTMutexInit o_handlers_mutex;
 
 /** For mime types set as "internal" in mimeconf: 
   * create appropriate handler object. */
@@ -143,6 +144,7 @@ void returnMimeHandler(Dijon::Filter *handler)
     typedef multimap<string, Dijon::Filter*>::value_type value_type;
     if (handler) {
 	handler->clear();
+	PTMutexLocker locker(o_handlers_mutex);
 	o_handlers.insert(value_type(handler->get_mime_type(), handler));
     }
 }
@@ -151,6 +153,7 @@ void clearMimeHandlerCache()
 {
     typedef multimap<string, Dijon::Filter*>::value_type value_type;
     map<string, Dijon::Filter *>::iterator it;
+    PTMutexLocker locker(o_handlers_mutex);
     for (it = o_handlers.begin(); it != o_handlers.end(); it++) {
 	delete it->second;
     }
@@ -165,6 +168,7 @@ Dijon::Filter *getMimeHandler(const string &mtype, RclConfig *cfg,
     LOGDEB2(("getMimeHandler: mtype [%s] filtertypes %d\n", 
              mtype.c_str(), filtertypes));
     Dijon::Filter *h = 0;
+    PTMutexLocker locker(o_handlers_mutex);
 
     // Get handler definition for mime type. We do this even if an
     // appropriate handler object may be in the cache (indexed by mime
