@@ -1,7 +1,4 @@
-#ifndef lint
-static char rcsid[] = "@(#$Id: advsearch_w.cpp,v 1.21 2008-09-25 06:00:24 dockes Exp $ (C) 2005 J.F.Dockes";
-#endif
-/*
+/* Copyright (C) 2005 J.F.Dockes 
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
  *   the Free Software Foundation; either version 2 of the License, or
@@ -51,8 +48,6 @@ using std::unique;
 #include "guiutils.h"
 #include "rclhelp.h"
 
-extern RclConfig *rclconfig;
-
 static const int initclausetypes[] = {1, 3, 0, 2, 5};
 static const unsigned int iclausescnt = sizeof(initclausetypes) / sizeof(int);
 static map<QString,QString> cat_translations;
@@ -271,7 +266,7 @@ void AdvSearch::fillFileTypes()
 
     QStringList ql;
     if (m_ignByCats == false) {
-	list<string> types = rclconfig->getAllMimeTypes();
+	list<string> types = theconfig->getAllMimeTypes();
 	for (list<string>::iterator it = types.begin(); 
 	     it != types.end(); it++) {
 	    QString qs = QString::fromUtf8(it->c_str());
@@ -280,7 +275,7 @@ void AdvSearch::fillFileTypes()
 	}
     } else {
 	list<string> cats;
-	rclconfig->getMimeCategories(cats);
+	theconfig->getMimeCategories(cats);
 	for (list<string>::const_iterator it = cats.begin();
 	     it != cats.end(); it++) {
 	    map<QString, QString>::const_iterator it1;
@@ -337,7 +332,7 @@ void AdvSearch::runSearch()
 		    cat = (const char *)qcat.toUtf8();
 		}
 		list<string> types;
-		rclconfig->getMimeCatTypes(cat, types);
+		theconfig->getMimeCatTypes(cat, types);
 		for (list<string>::const_iterator it = types.begin();
 		     it != types.end(); it++) {
 		    sdata->addFiletype(*it);
@@ -351,7 +346,8 @@ void AdvSearch::runSearch()
 
     if (!subtreeCMB->currentText().isEmpty()) {
 	QString current = subtreeCMB->currentText();
-	sdata->setTopdir((const char*)subtreeCMB->currentText().toUtf8());
+	sdata->setTopdir((const char*)subtreeCMB->currentText().toUtf8(),
+			 direxclCB->isChecked());
 	// Keep history list clean and sorted. Maybe there would be a
 	// simpler way to do this
 	list<QString> entries;
