@@ -1,7 +1,4 @@
-#ifndef lint
-static char rcsid[] = "@(#$Id: guiutils.cpp,v 1.40 2008-11-24 15:23:12 dockes Exp $ (C) 2005 Jean-Francois Dockes";
-#endif
-/*
+/* Copyright (C) 2005 Jean-Francois Dockes
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
  *   the Free Software Foundation; either version 2 of the License, or
@@ -122,6 +119,8 @@ void rwSettings(bool writing)
     SETTING_RW(prefs.showResultsAsTable, 
 	       "/Recoll/prefs/showResultsAsTable", Bool, false);
     SETTING_RW(prefs.maxhltextmbs, "/Recoll/prefs/preview/maxhltextmbs", Int, 3);
+    SETTING_RW(prefs.previewPlainPre, 
+	       "/Recoll/prefs/preview/plainPre", Bool, true);
     SETTING_RW(prefs.qtermcolor, "/Recoll/prefs/qtermcolor", String, "blue");
     if (!writing && prefs.qtermcolor == "")
 	prefs.qtermcolor = "blue";
@@ -147,12 +146,21 @@ void rwSettings(bool writing)
 	       "english");
     SETTING_RW(prefs.useDesktopOpen, 
 	       "/Recoll/prefs/useDesktopOpen", Bool, true);
+
     SETTING_RW(prefs.keepSort, 
 	       "/Recoll/prefs/keepSort", Bool, false);
+    SETTING_RW(prefs.sortField, "/Recoll/prefs/sortField", String, "");
     SETTING_RW(prefs.sortActive, 
 	       "/Recoll/prefs/sortActive", Bool, false);
     SETTING_RW(prefs.sortDesc, 
 	       "/Recoll/prefs/query/sortDesc", Bool, 0);
+    if (!writing) {
+	// Handle transition from older prefs which did not store sortColumn
+	// (Active always meant sort by date).
+	if (prefs.sortActive && prefs.sortField.isNull())
+	    prefs.sortField = "mtime";
+    }
+
     SETTING_RW(prefs.queryBuildAbstract, 
 	       "/Recoll/prefs/query/buildAbstract", Bool, true);
     SETTING_RW(prefs.queryReplaceAbstract, 
@@ -167,6 +175,8 @@ void rwSettings(bool writing)
 
     SETTING_RW(prefs.termMatchType, "/Recoll/prefs/query/termMatchType", 
 	       Int, 0);
+    // This is not really the current program version, just a value to
+    // be used in case we have incompatible changes one day
     SETTING_RW(prefs.rclVersion, "/Recoll/prefs/rclVersion", 
 	       Int, 1009);
 
