@@ -1,4 +1,4 @@
-/*
+/* Copyright (C) 2005 Jean-Francois Dockes 
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
  *   the Free Software Foundation; either version 2 of the License, or
@@ -16,25 +16,6 @@
  */
 #ifndef _GUIUTILS_H_INCLUDED_
 #define _GUIUTILS_H_INCLUDED_
-/* 
- * @(#$Id: guiutils.h,v 1.29 2008-10-03 08:09:35 dockes Exp $  (C) 2005 Jean-Francois Dockes 
- *                         jfd@recoll.org
- *
- *   This program is free software; you can redistribute it and/or modify
- *   it under the terms of the GNU General Public License as published by
- *   the Free Software Foundation; either version 2 of the License, or
- *   (at your option) any later version.
- *
- *   This program is distributed in the hope that it will be useful,
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *   GNU General Public License for more details.
- *
- *   You should have received a copy of the GNU General Public License
- *   along with this program; if not, write to the
- *   Free Software Foundation, Inc.,
- *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
- */
 
 #include <string>
 #include <list>
@@ -73,14 +54,22 @@ class PrefsPack {
     int pvwidth; // Preview window geom
     int pvheight;
     int ssearchTyp;
-    bool    useDesktopOpen; // typically xdg-open, instead of mimeview settings
-    bool    keepSort;   // Remember sort status between invocations
-    bool    sortActive; // Remembered sort state.
-    bool    sortDesc;  // ..
+    // Use single app (default: xdg-open), instead of per-mime settings
+    bool useDesktopOpen; 
+    // Remember sort state between invocations ?
+    bool keepSort;   
+    QString sortField;
+    bool sortActive; 
+    bool sortDesc; 
+    // Abstract preferences. Building abstracts can slow result display
     bool queryBuildAbstract;
     bool queryReplaceAbstract;
     bool startWithAdvSearchOpen;
+    // Try to display html if it exists in the internfile stack.
     bool previewHtml;
+    // Use <pre> tag to display highlighted text/plain inside html (else
+    // we use <br> at end of lines, which lets textedit wrap lines).
+    bool previewPlainPre; 
     bool collapseDuplicates;
     bool showResultsAsTable;
 
@@ -130,9 +119,8 @@ class PrefsPack {
 	queryReplaceAbstract(false),
 	startWithAdvSearchOpen(false),
 	termMatchType(0),
-	rclVersion(1009)
-	    {
-	    }
+	rclVersion(1505)
+    { }
 };
 
 /** Global preferences record */
