@@ -1,5 +1,4 @@
 <!DOCTYPE TS><TS>
-<defaultcodec></defaultcodec>
 <context>
     <name>AdvSearch</name>
     <message>
@@ -159,7 +158,7 @@ Drücken Sie Abbrechen, um die Konfigurationsdatei vor dem Start der Indizierung
     </message>
     <message>
         <source>Match &amp;Case</source>
-        <translation type="unfinished">Groß/Kleinschreibung &amp;beachten</translation>
+        <translation>Groß/Kleinschreibung &amp;beachten</translation>
     </message>
     <message>
         <source>Clear</source>
@@ -422,14 +421,6 @@ Please check the mimeconf file</source>
         <source>Missing helper programs</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Save file dialog</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Choose a file name to save under</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Document category filter</source>
         <translation type="unfinished"></translation>
@@ -451,6 +442,18 @@ Do you want to start the  preferences dialog ?</source>
         <source>Can&apos;t uncompress file: </source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Save file</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Result count (est.)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Query details</source>
+        <translation type="unfinished">Suchdetails</translation>
+    </message>
 </context>
 <context>
     <name>RclMainBase</name>
@@ -586,10 +589,6 @@ Do you want to start the  preferences dialog ?</source>
         <source>PgDown</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Shift+Home, Ctrl+S, Ctrl+Q, Ctrl+S</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>PgUp</source>
         <translation type="unfinished"></translation>
@@ -602,6 +601,113 @@ Do you want to start the  preferences dialog ?</source>
         <source>F11</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Shift+Home</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Full Screen</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>&amp;Erase search history</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>sortByDateAsc</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Sort by dates from oldest to newest</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>sortByDateDesc</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Sort by dates from newest to oldest</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Show Query Details</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Show results as table</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>RecollModel</name>
+    <message>
+        <source>Abstract</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Author</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Document size</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Document date</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>File size</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>File name</source>
+        <translation type="unfinished">Dateiname</translation>
+    </message>
+    <message>
+        <source>File date</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source> Ipath</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Keywords</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Mime type</source>
+        <translation type="unfinished">Mime Type</translation>
+    </message>
+    <message>
+        <source>Original character set</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Relevancy rating</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Title</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>URL</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Mtime</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Date</source>
+        <translation type="unfinished">Datum</translation>
+    </message>
+    <message>
+        <source>Date and time</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>ResList</name>
@@ -639,7 +745,7 @@ Do you want to start the  preferences dialog ?</source>
     </message>
     <message>
         <source>Query details</source>
-        <translation>Suchdetails</translation>
+        <translation type="obsolete">Suchdetails</translation>
     </message>
     <message>
         <source>(show query)</source>
@@ -649,14 +755,6 @@ Do you want to start the  preferences dialog ?</source>
         <source>Copy &amp;File Name</source>
         <translation>&amp;Dateinamen kopieren</translation>
     </message>
-    <message>
-        <source>filtered</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>sorted</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Document history</source>
         <translation type="unfinished">Dokumenthistorie</translation>
@@ -702,6 +800,25 @@ Do you want to start the  preferences dialog ?</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
+<context>
+    <name>ResTable</name>
+    <message>
+        <source>&amp;Reset sort</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>&amp;Delete column</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Add &quot;</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>&quot; column</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>SSearch</name>
     <message>
@@ -740,6 +857,30 @@ Do you want to start the  preferences dialog ?</source>
         <source>Out of memory</source>
         <translation>Kein freier Speicher mehr verfügbar</translation>
     </message>
+    <message>
+        <source>Enter query language expression. Cheat sheet:&lt;br&gt;
+&lt;i&gt;term1 term2&lt;/i&gt; : &apos;term1&apos; and &apos;term2&apos; in any field.&lt;br&gt;
+&lt;i&gt;field:term1&lt;/i&gt; : &apos;term1&apos; in field &apos;field&apos;.&lt;br&gt;
+ Standard field names/synonyms:&lt;br&gt;
+  title/subject/caption, author/from, recipient/to, filename, ext.&lt;br&gt;
+ Pseudo-fields: dir, mime/format, type/rclcat, date.&lt;br&gt;
+ Two date interval exemples: 2009-03-01/2009-05-20  2009-03-01/P2M.&lt;br&gt;
+&lt;i&gt;term1 term2 OR term3&lt;/i&gt; : term1 AND (term2 OR term3).&lt;br&gt;
+  No actual parentheses allowed.&lt;br&gt;
+&lt;i&gt;&quot;term1 term2&quot;&lt;/i&gt; : phrase (must occur exactly). Possible modifiers:&lt;br&gt;
+&lt;i&gt;&quot;term1 term2&quot;p&lt;/i&gt; : unordered proximity search with default distance.&lt;br&gt;
+Use &lt;b&gt;Show Query&lt;/b&gt; link when in doubt about result and see manual (&amp;lt;F1&gt;) for more detail.
+</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Enter file name wildcard expression.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Enter search terms here. Type ESC SPC for completions of current term.</source>
+        <translation type="unfinished">Suchausdruck hier eingeben. Drücken Sie ESC SPC für Vervollständigungen des aktuellen Ausdrucks</translation>
+    </message>
 </context>
 <context>
     <name>SSearchBase</name>
@@ -780,7 +921,7 @@ Do you want to start the  preferences dialog ?</source>
     <name>SearchClauseW</name>
     <message>
         <source>SearchClauseW</source>
-        <translation>SearchClauseW</translation>
+        <translation type="obsolete">SearchClauseW</translation>
     </message>
     <message>
         <source>Any of these</source>
@@ -819,38 +960,38 @@ Do you want to start the  preferences dialog ?</source>
     <name>SortForm</name>
     <message>
         <source>Date</source>
-        <translation>Datum</translation>
+        <translation type="obsolete">Datum</translation>
     </message>
     <message>
         <source>Mime type</source>
-        <translation>Mime Type</translation>
+        <translation type="obsolete">Mime Type</translation>
     </message>
 </context>
 <context>
     <name>SortFormBase</name>
     <message>
         <source>Sort Criteria</source>
-        <translation>Sortierkriterium</translation>
+        <translation type="obsolete">Sortierkriterium</translation>
     </message>
     <message>
         <source>Sort the</source>
-        <translation>Zeige die</translation>
+        <translation type="obsolete">Zeige die</translation>
     </message>
     <message>
         <source>most relevant results by:</source>
-        <translation>relevantesten Ergebnisse sortiert nach:</translation>
+        <translation type="obsolete">relevantesten Ergebnisse sortiert nach:</translation>
     </message>
     <message>
         <source>Descending</source>
-        <translation>Absteigend</translation>
+        <translation type="obsolete">Absteigend</translation>
     </message>
     <message>
         <source>Close</source>
-        <translation>Schließen</translation>
+        <translation type="obsolete">Schließen</translation>
     </message>
     <message>
         <source>Apply</source>
-        <translation>Übernehmen</translation>
+        <translation type="obsolete">Übernehmen</translation>
     </message>
 </context>
 <context>
@@ -877,16 +1018,12 @@ Do you want to start the  preferences dialog ?</source>
     </message>
     <message>
         <source>Term</source>
-        <translation>Ausdruck</translation>
+        <translation type="obsolete">Ausdruck</translation>
     </message>
     <message>
         <source>No db info.</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Doc. / Tot.</source>
-        <translation type="unfinished"></translation>
-    </message>
 </context>
 <context>
     <name>SpellW</name>
@@ -924,7 +1061,7 @@ Do you want to start the  preferences dialog ?</source>
     </message>
     <message>
         <source>Term</source>
-        <translation type="unfinished">Ausdruck</translation>
+        <translation>Ausdruck</translation>
     </message>
     <message>
         <source>Doc. / Tot.</source>
@@ -962,207 +1099,159 @@ Do you want to start the  preferences dialog ?</source>
     <name>UIPrefsDialogBase</name>
     <message>
         <source>User interface</source>
-        <translation>Benutzeroberfläche</translation>
+        <translation type="obsolete">Benutzeroberfläche</translation>
     </message>
     <message>
         <source>Number of entries in a result page</source>
-        <translation>Anzahl der Ergebnisse pro Seite</translation>
+        <translation type="obsolete">Anzahl der Ergebnisse pro Seite</translation>
     </message>
     <message>
         <source>Result list font</source>
-        <translation>Schriftart für Ergebnisliste</translation>
+        <translation type="obsolete">Schriftart für Ergebnisliste</translation>
     </message>
     <message>
         <source>Helvetica-10</source>
-        <translation>Helvetica-10</translation>
+        <translation type="obsolete">Helvetica-10</translation>
     </message>
     <message>
         <source>Opens a dialog to select the result list font</source>
-        <translation>Öffnet einen Dialog zur Auswahl der Schriftart für die Ergebnisliste</translation>
+        <translation type="obsolete">Öffnet einen Dialog zur Auswahl der Schriftart für die Ergebnisliste</translation>
     </message>
     <message>
         <source>Reset</source>
-        <translation>Reset</translation>
+        <translation type="obsolete">Reset</translation>
     </message>
     <message>
         <source>Resets the result list font to the system default</source>
-        <translation>Setzt die Schriftart für die Ergebnisliste zurück auf den Standardwert</translation>
+        <translation type="obsolete">Setzt die Schriftart für die Ergebnisliste zurück auf den Standardwert</translation>
     </message>
     <message>
         <source>Auto-start simple search on whitespace entry.</source>
-        <translation>Automatisch eine einfache Suche starten, wenn ein Worttrenner im Sucheingabefeld eingegeben wird.</translation>
+        <translation type="obsolete">Automatisch eine einfache Suche starten, wenn ein Worttrenner im Sucheingabefeld eingegeben wird.</translation>
     </message>
     <message>
         <source>Start with advanced search dialog open.</source>
-        <translation>Nach dem Start automatisch den Dialog für die erweiterte Suche öffnen.</translation>
+        <translation type="obsolete">Nach dem Start automatisch den Dialog für die erweiterte Suche öffnen.</translation>
     </message>
     <message>
         <source>Start with sort dialog open.</source>
-        <translation>Nach dem Start automatisch den Sortierdialog öffnen.</translation>
+        <translation type="obsolete">Nach dem Start automatisch den Sortierdialog öffnen.</translation>
     </message>
     <message>
         <source>Search parameters</source>
-        <translation>Suchparameter</translation>
+        <translation type="obsolete">Suchparameter</translation>
     </message>
     <message>
         <source>Stemming language</source>
-        <translation>Stemming Sprache</translation>
+        <translation type="obsolete">Stemming Sprache</translation>
     </message>
     <message>
         <source>Dynamically build abstracts</source>
-        <translation>Zusammenfassungen dynamisch erzeugen</translation>
+        <translation type="obsolete">Zusammenfassungen dynamisch erzeugen</translation>
     </message>
     <message>
         <source>Do we try to build abstracts for result list entries by using the context of query terms ? 
 May be slow for big documents.</source>
-        <translation>Festlegung ob Zusammenfassungen für Ergebnisse im Kontext der Suchparameter erzeugt werden (kann bei großen Dokumenten langsam sein).</translation>
+        <translation type="obsolete">Festlegung ob Zusammenfassungen für Ergebnisse im Kontext der Suchparameter erzeugt werden (kann bei großen Dokumenten langsam sein).</translation>
     </message>
     <message>
         <source>Replace abstracts from documents</source>
-        <translation>Ersetzen der Zusammenfassungen in den Dokumenten</translation>
+        <translation type="obsolete">Ersetzen der Zusammenfassungen in den Dokumenten</translation>
     </message>
     <message>
         <source>Do we synthetize an abstract even if the document seemed to have one?</source>
-        <translation>Festlegung ob eine Zusammenfassung auch dann erzeugt wird, wenn das Dokument schon eine Zusammenfassung enthält</translation>
+        <translation type="obsolete">Festlegung ob eine Zusammenfassung auch dann erzeugt wird, wenn das Dokument schon eine Zusammenfassung enthält</translation>
     </message>
     <message>
         <source>Synthetic abstract size (characters)</source>
-        <translation>Länge der erzeugten Zusammenfassung (Zeichen)</translation>
+        <translation type="obsolete">Länge der erzeugten Zusammenfassung (Zeichen)</translation>
     </message>
     <message>
         <source>Synthetic abstract context words</source>
-        <translation>Anzahl der Kontextworte in der Zusammenfassung</translation>
+        <translation type="obsolete">Anzahl der Kontextworte in der Zusammenfassung</translation>
     </message>
     <message>
         <source>External Indexes</source>
-        <translation>externe Indizes</translation>
+        <translation type="obsolete">externe Indizes</translation>
     </message>
     <message>
         <source>Add index</source>
-        <translation>Index hinzufügen</translation>
+        <translation type="obsolete">Index hinzufügen</translation>
     </message>
     <message>
         <source>Select the xapiandb directory for the index you want to add, then click Add Index</source>
-        <translation>Wählen Sie das xapiandb-Verzeichnis des zuzufügenden Indizes und klicken Sie auf Index hinzufügen</translation>
+        <translation type="obsolete">Wählen Sie das xapiandb-Verzeichnis des zuzufügenden Indizes und klicken Sie auf Index hinzufügen</translation>
     </message>
     <message>
         <source>Browse</source>
-        <translation>Auswahl</translation>
+        <translation type="obsolete">Auswahl</translation>
     </message>
     <message>
         <source>&amp;OK</source>
-        <translation>&amp;OK</translation>
+        <translation type="obsolete">&amp;OK</translation>
     </message>
     <message>
         <source>Apply changes</source>
-        <translation>Änderungen übernehmen</translation>
+        <translation type="obsolete">Änderungen übernehmen</translation>
     </message>
     <message>
         <source>&amp;Cancel</source>
-        <translation>&amp;Abbrechen</translation>
+        <translation type="obsolete">&amp;Abbrechen</translation>
     </message>
     <message>
         <source>Discard changes</source>
-        <translation>Änderungen verwerfen</translation>
+        <translation type="obsolete">Änderungen verwerfen</translation>
     </message>
     <message>
         <source>Result paragraph&lt;br&gt;format string</source>
-        <translation>Formatstring 
+        <translation type="obsolete">Formatstring 
 für Ergebnisse</translation>
     </message>
     <message>
         <source>Automatically add phrase to simple searches</source>
-        <translation>Automatisches Zufügen von Sätzen zu einfachen Suchen</translation>
+        <translation type="obsolete">Automatisches Zufügen von Sätzen zu einfachen Suchen</translation>
     </message>
     <message>
         <source>A search for [rolling stones] (2 terms) will be changed to [rolling or stones or (rolling phrase 2 stones)]. 
 This should give higher precedence to the results where the search terms appear exactly as entered.</source>
-        <translation>Eine Suche nach [Jürgen Klinsmann] wird geändert nach [Jürgen OR Klinsmann OR (Jürgen PHRASE 2 Klinsmann)].
+        <translation type="obsolete">Eine Suche nach [Jürgen Klinsmann] wird geändert nach [Jürgen OR Klinsmann OR (Jürgen PHRASE 2 Klinsmann)].
 Dadurch sollten Ergebnisse, die exakte Übereinstimmungen der Suchworte enthalten, stärker gewichtet werden.</translation>
     </message>
     <message>
         <source>User preferences</source>
-        <translation>Benutzereinstellungen</translation>
+        <translation type="obsolete">Benutzereinstellungen</translation>
     </message>
     <message>
         <source>Use desktop preferences to choose document editor.</source>
-        <translation>Die Einstellung des Dokumenteneditors erfolgt in den Desktopvoreinstellungen.</translation>
+        <translation type="obsolete">Die Einstellung des Dokumenteneditors erfolgt in den Desktopvoreinstellungen.</translation>
     </message>
     <message>
         <source>External indexes</source>
-        <translation>Externe Indizes</translation>
+        <translation type="obsolete">Externe Indizes</translation>
     </message>
     <message>
         <source>Toggle selected</source>
-        <translation>Auswahl umkehren</translation>
+        <translation type="obsolete">Auswahl umkehren</translation>
     </message>
     <message>
         <source>Activate All</source>
-        <translation>Alle Auswählen</translation>
+        <translation type="obsolete">Alle Auswählen</translation>
     </message>
     <message>
         <source>Deactivate All</source>
-        <translation>Alle Abwählen</translation>
+        <translation type="obsolete">Alle Abwählen</translation>
     </message>
     <message>
         <source>Remove selected</source>
-        <translation>Ausgewählte entfernen</translation>
+        <translation type="obsolete">Ausgewählte entfernen</translation>
     </message>
     <message>
         <source>Remove from list. This has no effect on the disk index.</source>
-        <translation>Aus der Liste entfernen. Dies hat keinen Einfluss auf den gespeicherten Index.</translation>
-    </message>
-    <message>
-        <source>Defines the format for each result list paragraph. Use qt html format and printf-like replacements:&lt;br&gt;%A Abstract&lt;br&gt; %D Date&lt;br&gt; %I Icon image name&lt;br&gt; %K Keywords (if any)&lt;br&gt; %L Preview and Edit links&lt;br&gt; %M Mime type&lt;br&gt; %N Result number&lt;br&gt; %R Relevance percentage&lt;br&gt; %S Size information&lt;br&gt; %T Title&lt;br&gt; %U Url&lt;br&gt;</source>
-        <translation type="unfinished"></translation>
+        <translation type="obsolete">Aus der Liste entfernen. Dies hat keinen Einfluss auf den gespeicherten Index.</translation>
     </message>
     <message>
         <source>Remember sort activation state.</source>
-        <translation>Speichern, ob Sortieren aktiviert ist.</translation>
-    </message>
-    <message>
-        <source>Maximum text size highlighted for preview (megabytes)</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Texts over this size will not be highlighted in preview (too slow).</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Highlight color for query terms</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Prefer Html to plain text for preview.</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>If checked, results with the same content under different names will only be shown once.</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Hide duplicate results.</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Choose editor applications</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Display category filter as toolbar instead of button panel (needs restart).</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>The words in the list will be automatically turned to ext:xxx clauses in the query language entry.</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Query language magic file name suffixes.</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Enable</source>
-        <translation type="unfinished"></translation>
+        <translation type="obsolete">Speichern, ob Sortieren aktiviert ist.</translation>
     </message>
 </context>
 <context>
@@ -1171,16 +1260,24 @@ Dadurch sollten Ergebnisse, die exakte Übereinstimmungen der Suchworte enthalte
         <source>Changing actions with different current values</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Mime type</source>
+        <translation>Mime Type</translation>
+    </message>
+    <message>
+        <source>Command</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>ViewActionBase</name>
     <message>
         <source>File type</source>
-        <translation>Dateityp</translation>
+        <translation type="obsolete">Dateityp</translation>
     </message>
     <message>
         <source>Action</source>
-        <translation>Aktion</translation>
+        <translation type="obsolete">Aktion</translation>
     </message>
     <message>
         <source>Select one or several file types, then click Change Action to modify the program used to open them</source>
@@ -1237,13 +1334,6 @@ Dadurch sollten Ergebnisse, die exakte Übereinstimmungen der Suchworte enthalte
         <translation>Kann Konfigurationsdatei nicht schreiben</translation>
     </message>
 </context>
-<context>
-    <name>confgui::ConfParamFNW</name>
-    <message>
-        <source>Browse</source>
-        <translation type="unfinished"></translation>
-    </message>
-</context>
 <context>
     <name>confgui::ConfParamSLW</name>
     <message>
@@ -1388,4 +1478,203 @@ This will help searching very big text  files (ie: log files).</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
+<context>
+    <name>uiPrefsDialogBase</name>
+    <message>
+        <source>User preferences</source>
+        <translation>Benutzereinstellungen</translation>
+    </message>
+    <message>
+        <source>User interface</source>
+        <translation>Benutzeroberfläche</translation>
+    </message>
+    <message>
+        <source>Number of entries in a result page</source>
+        <translation>Anzahl der Ergebnisse pro Seite</translation>
+    </message>
+    <message>
+        <source>If checked, results with the same content under different names will only be shown once.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Hide duplicate results.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Highlight color for query terms</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Result list font</source>
+        <translation>Schriftart für Ergebnisliste</translation>
+    </message>
+    <message>
+        <source>Opens a dialog to select the result list font</source>
+        <translation>Öffnet einen Dialog zur Auswahl der Schriftart für die Ergebnisliste</translation>
+    </message>
+    <message>
+        <source>Helvetica-10</source>
+        <translation>Helvetica-10</translation>
+    </message>
+    <message>
+        <source>Resets the result list font to the system default</source>
+        <translation>Setzt die Schriftart für die Ergebnisliste zurück auf den Standardwert</translation>
+    </message>
+    <message>
+        <source>Reset</source>
+        <translation>Reset</translation>
+    </message>
+    <message>
+        <source>Defines the format for each result list paragraph. Use qt html format and printf-like replacements:&lt;br&gt;%A Abstract&lt;br&gt; %D Date&lt;br&gt; %I Icon image name&lt;br&gt; %K Keywords (if any)&lt;br&gt; %L Preview and Edit links&lt;br&gt; %M Mime type&lt;br&gt; %N Result number&lt;br&gt; %R Relevance percentage&lt;br&gt; %S Size information&lt;br&gt; %T Title&lt;br&gt; %U Url&lt;br&gt;</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Result paragraph&lt;br&gt;format string</source>
+        <translation>Formatstring 
+für Ergebnisse</translation>
+    </message>
+    <message>
+        <source>Texts over this size will not be highlighted in preview (too slow).</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Maximum text size highlighted for preview (megabytes)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Use desktop preferences to choose document editor.</source>
+        <translation>Die Einstellung des Dokumenteneditors erfolgt in den Desktopvoreinstellungen.</translation>
+    </message>
+    <message>
+        <source>Choose editor applications</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Display category filter as toolbar instead of button panel (needs restart).</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Auto-start simple search on whitespace entry.</source>
+        <translation>Automatisch eine einfache Suche starten, wenn ein Worttrenner im Sucheingabefeld eingegeben wird.</translation>
+    </message>
+    <message>
+        <source>Start with advanced search dialog open.</source>
+        <translation>Nach dem Start automatisch den Dialog für die erweiterte Suche öffnen.</translation>
+    </message>
+    <message>
+        <source>Start with sort dialog open.</source>
+        <translation type="obsolete">Nach dem Start automatisch den Sortierdialog öffnen.</translation>
+    </message>
+    <message>
+        <source>Remember sort activation state.</source>
+        <translation>Speichern, ob Sortieren aktiviert ist.</translation>
+    </message>
+    <message>
+        <source>Prefer Html to plain text for preview.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Search parameters</source>
+        <translation>Suchparameter</translation>
+    </message>
+    <message>
+        <source>Stemming language</source>
+        <translation>Stemming Sprache</translation>
+    </message>
+    <message>
+        <source>A search for [rolling stones] (2 terms) will be changed to [rolling or stones or (rolling phrase 2 stones)]. 
+This should give higher precedence to the results where the search terms appear exactly as entered.</source>
+        <translation>Eine Suche nach [Jürgen Klinsmann] wird geändert nach [Jürgen OR Klinsmann OR (Jürgen PHRASE 2 Klinsmann)].
+Dadurch sollten Ergebnisse, die exakte Übereinstimmungen der Suchworte enthalten, stärker gewichtet werden.</translation>
+    </message>
+    <message>
+        <source>Automatically add phrase to simple searches</source>
+        <translation>Automatisches Zufügen von Sätzen zu einfachen Suchen</translation>
+    </message>
+    <message>
+        <source>Do we try to build abstracts for result list entries by using the context of query terms ? 
+May be slow for big documents.</source>
+        <translation>Festlegung ob Zusammenfassungen für Ergebnisse im Kontext der Suchparameter erzeugt werden (kann bei großen Dokumenten langsam sein).</translation>
+    </message>
+    <message>
+        <source>Dynamically build abstracts</source>
+        <translation>Zusammenfassungen dynamisch erzeugen</translation>
+    </message>
+    <message>
+        <source>Do we synthetize an abstract even if the document seemed to have one?</source>
+        <translation>Festlegung ob eine Zusammenfassung auch dann erzeugt wird, wenn das Dokument schon eine Zusammenfassung enthält</translation>
+    </message>
+    <message>
+        <source>Replace abstracts from documents</source>
+        <translation>Ersetzen der Zusammenfassungen in den Dokumenten</translation>
+    </message>
+    <message>
+        <source>Synthetic abstract size (characters)</source>
+        <translation>Länge der erzeugten Zusammenfassung (Zeichen)</translation>
+    </message>
+    <message>
+        <source>Synthetic abstract context words</source>
+        <translation>Anzahl der Kontextworte in der Zusammenfassung</translation>
+    </message>
+    <message>
+        <source>The words in the list will be automatically turned to ext:xxx clauses in the query language entry.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Query language magic file name suffixes.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Enable</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>External Indexes</source>
+        <translation>externe Indizes</translation>
+    </message>
+    <message>
+        <source>Toggle selected</source>
+        <translation>Auswahl umkehren</translation>
+    </message>
+    <message>
+        <source>Activate All</source>
+        <translation>Alle Auswählen</translation>
+    </message>
+    <message>
+        <source>Deactivate All</source>
+        <translation>Alle Abwählen</translation>
+    </message>
+    <message>
+        <source>Remove from list. This has no effect on the disk index.</source>
+        <translation>Aus der Liste entfernen. Dies hat keinen Einfluss auf den gespeicherten Index.</translation>
+    </message>
+    <message>
+        <source>Remove selected</source>
+        <translation>Ausgewählte entfernen</translation>
+    </message>
+    <message>
+        <source>Click to add another index directory to the list</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Add index</source>
+        <translation>Index hinzufügen</translation>
+    </message>
+    <message>
+        <source>Apply changes</source>
+        <translation>Änderungen übernehmen</translation>
+    </message>
+    <message>
+        <source>&amp;OK</source>
+        <translation>&amp;OK</translation>
+    </message>
+    <message>
+        <source>Discard changes</source>
+        <translation>Änderungen verwerfen</translation>
+    </message>
+    <message>
+        <source>&amp;Cancel</source>
+        <translation>&amp;Abbrechen</translation>
+    </message>
+</context>
 </TS>
