@@ -425,11 +425,11 @@ Please check the mimeconf file</source>
     </message>
     <message>
         <source>Save file dialog</source>
-        <translation>Сохранить файл</translation>
+        <translation type="obsolete">Сохранить файл</translation>
     </message>
     <message>
         <source>Choose a file name to save under</source>
-        <translation>Выберите имя файла для сохранения</translation>
+        <translation type="obsolete">Выберите имя файла для сохранения</translation>
     </message>
     <message>
         <source>Document category filter</source>
@@ -453,6 +453,18 @@ Do you want to start the  preferences dialog ?</source>
         <source>Can&apos;t uncompress file: </source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Save file</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Result count (est.)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Query details</source>
+        <translation type="unfinished">Подробности запроса</translation>
+    </message>
 </context>
 <context>
     <name>RclMainBase</name>
@@ -588,10 +600,6 @@ Do you want to start the  preferences dialog ?</source>
         <source>PgDown</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Shift+Home, Ctrl+S, Ctrl+Q, Ctrl+S</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>PgUp</source>
         <translation type="unfinished"></translation>
@@ -604,6 +612,113 @@ Do you want to start the  preferences dialog ?</source>
         <source>F11</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Shift+Home</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Full Screen</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>&amp;Erase search history</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>sortByDateAsc</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Sort by dates from oldest to newest</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>sortByDateDesc</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Sort by dates from newest to oldest</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Show Query Details</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Show results as table</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>RecollModel</name>
+    <message>
+        <source>Abstract</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Author</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Document size</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Document date</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>File size</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>File name</source>
+        <translation type="unfinished">Имя файла</translation>
+    </message>
+    <message>
+        <source>File date</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source> Ipath</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Keywords</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Mime type</source>
+        <translation type="unfinished">Тип MIME</translation>
+    </message>
+    <message>
+        <source>Original character set</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Relevancy rating</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Title</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>URL</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Mtime</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Date</source>
+        <translation type="unfinished">Дата</translation>
+    </message>
+    <message>
+        <source>Date and time</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>ResList</name>
@@ -637,7 +752,7 @@ Do you want to start the  preferences dialog ?</source>
     </message>
     <message>
         <source>Query details</source>
-        <translation>Подробности запроса</translation>
+        <translation type="obsolete">Подробности запроса</translation>
     </message>
     <message>
         <source>(show query)</source>
@@ -653,11 +768,11 @@ Do you want to start the  preferences dialog ?</source>
     </message>
     <message>
         <source>filtered</source>
-        <translation>фильтрованное</translation>
+        <translation type="obsolete">фильтрованное</translation>
     </message>
     <message>
         <source>sorted</source>
-        <translation>сортированное</translation>
+        <translation type="obsolete">сортированное</translation>
     </message>
     <message>
         <source>Document history</source>
@@ -704,6 +819,25 @@ Do you want to start the  preferences dialog ?</source>
         <translation>по</translation>
     </message>
 </context>
+<context>
+    <name>ResTable</name>
+    <message>
+        <source>&amp;Reset sort</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>&amp;Delete column</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Add &quot;</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>&quot; column</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>SSearch</name>
     <message>
@@ -742,12 +876,36 @@ Do you want to start the  preferences dialog ?</source>
         <source>Out of memory</source>
         <translation>Недостаточно памяти</translation>
     </message>
+    <message>
+        <source>Enter query language expression. Cheat sheet:&lt;br&gt;
+&lt;i&gt;term1 term2&lt;/i&gt; : &apos;term1&apos; and &apos;term2&apos; in any field.&lt;br&gt;
+&lt;i&gt;field:term1&lt;/i&gt; : &apos;term1&apos; in field &apos;field&apos;.&lt;br&gt;
+ Standard field names/synonyms:&lt;br&gt;
+  title/subject/caption, author/from, recipient/to, filename, ext.&lt;br&gt;
+ Pseudo-fields: dir, mime/format, type/rclcat, date.&lt;br&gt;
+ Two date interval exemples: 2009-03-01/2009-05-20  2009-03-01/P2M.&lt;br&gt;
+&lt;i&gt;term1 term2 OR term3&lt;/i&gt; : term1 AND (term2 OR term3).&lt;br&gt;
+  No actual parentheses allowed.&lt;br&gt;
+&lt;i&gt;&quot;term1 term2&quot;&lt;/i&gt; : phrase (must occur exactly). Possible modifiers:&lt;br&gt;
+&lt;i&gt;&quot;term1 term2&quot;p&lt;/i&gt; : unordered proximity search with default distance.&lt;br&gt;
+Use &lt;b&gt;Show Query&lt;/b&gt; link when in doubt about result and see manual (&amp;lt;F1&gt;) for more detail.
+</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Enter file name wildcard expression.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Enter search terms here. Type ESC SPC for completions of current term.</source>
+        <translation>Введите поисковые слова.  Можно нажать Esc-пробел для дополнения текущего слова.</translation>
+    </message>
 </context>
 <context>
     <name>SSearchBase</name>
     <message>
         <source>SSearchBase</source>
-        <translation></translation>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <source>Clear</source>
@@ -780,10 +938,6 @@ Do you want to start the  preferences dialog ?</source>
 </context>
 <context>
     <name>SearchClauseW</name>
-    <message>
-        <source>SearchClauseW</source>
-        <translation></translation>
-    </message>
     <message>
         <source>Any of these</source>
         <translation>с любыми словами</translation>
@@ -821,38 +975,38 @@ Do you want to start the  preferences dialog ?</source>
     <name>SortForm</name>
     <message>
         <source>Date</source>
-        <translation>Дата</translation>
+        <translation type="obsolete">Дата</translation>
     </message>
     <message>
         <source>Mime type</source>
-        <translation>Тип MIME</translation>
+        <translation type="obsolete">Тип MIME</translation>
     </message>
 </context>
 <context>
     <name>SortFormBase</name>
     <message>
         <source>Sort Criteria</source>
-        <translation>Критерии сортировки</translation>
+        <translation type="obsolete">Критерии сортировки</translation>
     </message>
     <message>
         <source>Sort the</source>
-        <translation>Сортировать</translation>
+        <translation type="obsolete">Сортировать</translation>
     </message>
     <message>
         <source>most relevant results by:</source>
-        <translation>наиболее похожих результатов по:</translation>
+        <translation type="obsolete">наиболее похожих результатов по:</translation>
     </message>
     <message>
         <source>Descending</source>
-        <translation>убыванию</translation>
+        <translation type="obsolete">убыванию</translation>
     </message>
     <message>
         <source>Close</source>
-        <translation>Закрыть</translation>
+        <translation type="obsolete">Закрыть</translation>
     </message>
     <message>
         <source>Apply</source>
-        <translation>Применить</translation>
+        <translation type="obsolete">Применить</translation>
     </message>
 </context>
 <context>
@@ -867,7 +1021,7 @@ Do you want to start the  preferences dialog ?</source>
     </message>
     <message>
         <source>Alt+E</source>
-        <translation></translation>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <source>&amp;Close</source>
@@ -879,16 +1033,12 @@ Do you want to start the  preferences dialog ?</source>
     </message>
     <message>
         <source>Term</source>
-        <translation>Слово</translation>
+        <translation type="obsolete">Слово</translation>
     </message>
     <message>
         <source>No db info.</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Doc. / Tot.</source>
-        <translation type="unfinished"></translation>
-    </message>
 </context>
 <context>
     <name>SpellW</name>
@@ -926,7 +1076,7 @@ Do you want to start the  preferences dialog ?</source>
     </message>
     <message>
         <source>Term</source>
-        <translation type="unfinished">Слово</translation>
+        <translation>Слово</translation>
     </message>
     <message>
         <source>Doc. / Tot.</source>
@@ -964,207 +1114,195 @@ Do you want to start the  preferences dialog ?</source>
     <name>UIPrefsDialogBase</name>
     <message>
         <source>User interface</source>
-        <translation>Интерфейс</translation>
+        <translation type="obsolete">Интерфейс</translation>
     </message>
     <message>
         <source>Number of entries in a result page</source>
-        <translation>Количество записей на страницу результатов</translation>
+        <translation type="obsolete">Количество записей на страницу результатов</translation>
     </message>
     <message>
         <source>Result list font</source>
-        <translation>Шрифт списка результатов</translation>
+        <translation type="obsolete">Шрифт списка результатов</translation>
     </message>
     <message>
         <source>Helvetica-10</source>
-        <translation>Helvetica-10</translation>
+        <translation type="obsolete">Helvetica-10</translation>
     </message>
     <message>
         <source>Opens a dialog to select the result list font</source>
-        <translation>Открывает диалог выбора шрифта списка результатов</translation>
+        <translation type="obsolete">Открывает диалог выбора шрифта списка результатов</translation>
     </message>
     <message>
         <source>Reset</source>
-        <translation>Вернуть</translation>
+        <translation type="obsolete">Вернуть</translation>
     </message>
     <message>
         <source>Resets the result list font to the system default</source>
-        <translation>Устанавливает шрифт списка результатов в обычный</translation>
+        <translation type="obsolete">Устанавливает шрифт списка результатов в обычный</translation>
     </message>
     <message>
         <source>Auto-start simple search on whitespace entry.</source>
-        <translation>Начинать простой поиск по вводу пробела.</translation>
+        <translation type="obsolete">Начинать простой поиск по вводу пробела.</translation>
     </message>
     <message>
         <source>Start with advanced search dialog open.</source>
-        <translation>Открывать диалог сложного поиска при запуске.</translation>
+        <translation type="obsolete">Открывать диалог сложного поиска при запуске.</translation>
     </message>
     <message>
         <source>Start with sort dialog open.</source>
-        <translation>Открывать диалог сортировки при запуске.</translation>
+        <translation type="obsolete">Открывать диалог сортировки при запуске.</translation>
     </message>
     <message>
         <source>Search parameters</source>
-        <translation>Параметры поиска</translation>
+        <translation type="obsolete">Параметры поиска</translation>
     </message>
     <message>
         <source>Stemming language</source>
-        <translation>Язык словоформ</translation>
+        <translation type="obsolete">Язык словоформ</translation>
     </message>
     <message>
         <source>Dynamically build abstracts</source>
-        <translation>Динамическое выделение конспекта</translation>
+        <translation type="obsolete">Динамическое выделение конспекта</translation>
     </message>
     <message>
         <source>Do we try to build abstracts for result list entries by using the context of query terms ? 
 May be slow for big documents.</source>
-        <translation>Следует ли пытаться построить конспект из найденных документов, опираясь на контекст ключевых слов?
+        <translation type="obsolete">Следует ли пытаться построить конспект из найденных документов, опираясь на контекст ключевых слов?
 Может быть медленным для больших документов.</translation>
     </message>
     <message>
         <source>Replace abstracts from documents</source>
-        <translation>Замещать конспект, содержащийся в документах</translation>
+        <translation type="obsolete">Замещать конспект, содержащийся в документах</translation>
     </message>
     <message>
         <source>Do we synthetize an abstract even if the document seemed to have one?</source>
-        <translation>Создавать ли конспект, если документ уже имеет его?</translation>
+        <translation type="obsolete">Создавать ли конспект, если документ уже имеет его?</translation>
     </message>
     <message>
         <source>Synthetic abstract size (characters)</source>
-        <translation>Размер создаваемого конспекта (в символах)</translation>
+        <translation type="obsolete">Размер создаваемого конспекта (в символах)</translation>
     </message>
     <message>
         <source>Synthetic abstract context words</source>
-        <translation>Контекстных слов</translation>
+        <translation type="obsolete">Контекстных слов</translation>
     </message>
     <message>
         <source>External Indexes</source>
-        <translation>Внешние индексы</translation>
+        <translation type="obsolete">Внешние индексы</translation>
     </message>
     <message>
         <source>Add index</source>
-        <translation>Добавить индекс</translation>
+        <translation type="obsolete">Добавить индекс</translation>
     </message>
     <message>
         <source>Select the xapiandb directory for the index you want to add, then click Add Index</source>
-        <translation>Выберите нужный каталог с индексом Xapian и нажмите &quot;Добавить индекс&quot;</translation>
+        <translation type="obsolete">Выберите нужный каталог с индексом Xapian и нажмите &quot;Добавить индекс&quot;</translation>
     </message>
     <message>
         <source>Browse</source>
-        <translation>Просмотр</translation>
+        <translation type="obsolete">Просмотр</translation>
     </message>
     <message>
         <source>&amp;OK</source>
-        <translation>&amp;OK</translation>
+        <translation type="obsolete">&amp;OK</translation>
     </message>
     <message>
         <source>Apply changes</source>
-        <translation>Применить изменения</translation>
+        <translation type="obsolete">Применить изменения</translation>
     </message>
     <message>
         <source>&amp;Cancel</source>
-        <translation>&amp;Отмена</translation>
+        <translation type="obsolete">&amp;Отмена</translation>
     </message>
     <message>
         <source>Discard changes</source>
-        <translation>Отменить изменения</translation>
+        <translation type="obsolete">Отменить изменения</translation>
     </message>
     <message>
         <source>Result paragraph&lt;br&gt;format string</source>
-        <translation>Строка форматирования&lt;br&gt;блока результатов</translation>
+        <translation type="obsolete">Строка форматирования&lt;br&gt;блока результатов</translation>
     </message>
     <message>
         <source>Automatically add phrase to simple searches</source>
-        <translation>Автоматически добавлять фразу при простом поиске</translation>
+        <translation type="obsolete">Автоматически добавлять фразу при простом поиске</translation>
     </message>
     <message>
         <source>A search for [rolling stones] (2 terms) will be changed to [rolling or stones or (rolling phrase 2 stones)]. 
 This should give higher precedence to the results where the search terms appear exactly as entered.</source>
-        <translation>Поиск [rolling stones] (два слова) будет изменён на [rolling или stones или (rolling phrase 2 stones)].
+        <translation type="obsolete">Поиск [rolling stones] (два слова) будет изменён на [rolling или stones или (rolling phrase 2 stones)].
 Это может поднять результаты, для которых слова следуют именно в том порядке, как введены.</translation>
     </message>
     <message>
         <source>User preferences</source>
-        <translation>Предпочтения</translation>
+        <translation type="obsolete">Предпочтения</translation>
     </message>
     <message>
         <source>Use desktop preferences to choose document editor.</source>
-        <translation>Использовать десктопные настройки для выбора редактора документов.</translation>
+        <translation type="obsolete">Использовать десктопные настройки для выбора редактора документов.</translation>
     </message>
     <message>
         <source>External indexes</source>
-        <translation>Внешние индексы</translation>
+        <translation type="obsolete">Внешние индексы</translation>
     </message>
     <message>
         <source>Toggle selected</source>
-        <translation>Переключить выделенные</translation>
+        <translation type="obsolete">Переключить выделенные</translation>
     </message>
     <message>
         <source>Activate All</source>
-        <translation>Включить все</translation>
+        <translation type="obsolete">Включить все</translation>
     </message>
     <message>
         <source>Remove selected</source>
-        <translation>Удалить выделенные</translation>
+        <translation type="obsolete">Удалить выделенные</translation>
     </message>
     <message>
         <source>Remove from list. This has no effect on the disk index.</source>
-        <translation>Удалить из списка. Индекс на диске без изменений.</translation>
+        <translation type="obsolete">Удалить из списка. Индекс на диске без изменений.</translation>
     </message>
     <message>
         <source>Defines the format for each result list paragraph. Use qt html format and printf-like replacements:&lt;br&gt;%A Abstract&lt;br&gt; %D Date&lt;br&gt; %I Icon image name&lt;br&gt; %K Keywords (if any)&lt;br&gt; %L Preview and Edit links&lt;br&gt; %M Mime type&lt;br&gt; %N Result number&lt;br&gt; %R Relevance percentage&lt;br&gt; %S Size information&lt;br&gt; %T Title&lt;br&gt; %U Url&lt;br&gt;</source>
-        <translation>Определяет формат каждого блока списка результатов. Используйте html-формат qt и замены в стиле printf:&lt;br&gt;%A аннотация&lt;br&gt; %D дата&lt;br&gt; %I название пиктограммы&lt;br&gt; %K ключевые слова (если есть)&lt;br&gt; %L ссылки предварительного просмотра и редактирования&lt;br&gt; %M тип MIME&lt;br&gt; %N количество результатов&lt;br&gt; %R релевантность&lt;br&gt; %S размер&lt;br&gt; %T заголовок&lt;br&gt; %U URL&lt;br&gt;</translation>
+        <translation type="obsolete">Определяет формат каждого блока списка результатов. Используйте html-формат qt и замены в стиле printf:&lt;br&gt;%A аннотация&lt;br&gt; %D дата&lt;br&gt; %I название пиктограммы&lt;br&gt; %K ключевые слова (если есть)&lt;br&gt; %L ссылки предварительного просмотра и редактирования&lt;br&gt; %M тип MIME&lt;br&gt; %N количество результатов&lt;br&gt; %R релевантность&lt;br&gt; %S размер&lt;br&gt; %T заголовок&lt;br&gt; %U URL&lt;br&gt;</translation>
     </message>
     <message>
         <source>Remember sort activation state.</source>
-        <translation>Запомнить состояние сортировки.</translation>
+        <translation type="obsolete">Запомнить состояние сортировки.</translation>
     </message>
     <message>
         <source>Maximum text size highlighted for preview (megabytes)</source>
-        <translation>Максимальный объём текста с выделением при просмотре (Мб)</translation>
+        <translation type="obsolete">Максимальный объём текста с выделением при просмотре (Мб)</translation>
     </message>
     <message>
         <source>Texts over this size will not be highlighted in preview (too slow).</source>
-        <translation>Тексты большего размера не будут подсвечиваться при предварительном просмотре (медленно).</translation>
+        <translation type="obsolete">Тексты большего размера не будут подсвечиваться при предварительном просмотре (медленно).</translation>
     </message>
     <message>
         <source>Highlight color for query terms</source>
-        <translation>Цвет выделения ключевых слов</translation>
+        <translation type="obsolete">Цвет выделения ключевых слов</translation>
     </message>
     <message>
         <source>Deactivate All</source>
-        <translation>Выключить все</translation>
+        <translation type="obsolete">Выключить все</translation>
     </message>
     <message>
         <source>Prefer Html to plain text for preview.</source>
-        <translation>Предпочитать HTML тексту для предпросмотра</translation>
+        <translation type="obsolete">Предпочитать HTML тексту для предпросмотра</translation>
     </message>
     <message>
         <source>If checked, results with the same content under different names will only be shown once.</source>
-        <translation>Показывать результаты с тем же содержанием под разными именами не более одного раза</translation>
+        <translation type="obsolete">Показывать результаты с тем же содержанием под разными именами не более одного раза</translation>
     </message>
     <message>
         <source>Hide duplicate results.</source>
-        <translation>Прятать дубликаты</translation>
+        <translation type="obsolete">Прятать дубликаты</translation>
     </message>
     <message>
         <source>Choose editor applications</source>
-        <translation>Выбор редакторов</translation>
+        <translation type="obsolete">Выбор редакторов</translation>
     </message>
     <message>
         <source>Display category filter as toolbar instead of button panel (needs restart).</source>
-        <translation>Показывать фильтр категории документа в виде выпадающего списка, а не панели с кнопками (требуется перезапуск).</translation>
-    </message>
-    <message>
-        <source>The words in the list will be automatically turned to ext:xxx clauses in the query language entry.</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Query language magic file name suffixes.</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Enable</source>
-        <translation type="unfinished"></translation>
+        <translation type="obsolete">Показывать фильтр категории документа в виде выпадающего списка, а не панели с кнопками (требуется перезапуск).</translation>
     </message>
 </context>
 <context>
@@ -1173,16 +1311,24 @@ This should give higher precedence to the results where the search terms appear
         <source>Changing actions with different current values</source>
         <translation>Изменение действий с различными текущими значениями</translation>
     </message>
+    <message>
+        <source>Mime type</source>
+        <translation>Тип MIME</translation>
+    </message>
+    <message>
+        <source>Command</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>ViewActionBase</name>
     <message>
         <source>File type</source>
-        <translation>Тип файла</translation>
+        <translation type="obsolete">Тип файла</translation>
     </message>
     <message>
         <source>Action</source>
-        <translation>Действие</translation>
+        <translation type="obsolete">Действие</translation>
     </message>
     <message>
         <source>Select one or several file types, then click Change Action to modify the program used to open them</source>
@@ -1243,7 +1389,7 @@ This should give higher precedence to the results where the search terms appear
     <name>confgui::ConfParamFNW</name>
     <message>
         <source>Browse</source>
-        <translation>Просмотр</translation>
+        <translation type="obsolete">Просмотр</translation>
     </message>
 </context>
 <context>
@@ -1261,7 +1407,7 @@ This should give higher precedence to the results where the search terms appear
     <name>confgui::ConfSubPanelW</name>
     <message>
         <source>Global</source>
-        <translation></translation>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <source>Max. compressed file size (KB)</source>
@@ -1305,7 +1451,7 @@ This will help searching very big text  files (ie: log files).</source>
     <name>confgui::ConfTopPanelW</name>
     <message>
         <source>Top directories</source>
-        <translation></translation>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <source>The list of directories where recursive indexing starts. Default: your home.</source>
@@ -1392,4 +1538,203 @@ This will help searching very big text  files (ie: log files).</source>
         <translation>Отключает использование aspell для генерации приближений написания в навигаторе терминов.&lt;br&gt; Полезно, если aspell отсутствует или сломан. </translation>
     </message>
 </context>
+<context>
+    <name>uiPrefsDialogBase</name>
+    <message>
+        <source>User preferences</source>
+        <translation>Предпочтения</translation>
+    </message>
+    <message>
+        <source>User interface</source>
+        <translation>Интерфейс</translation>
+    </message>
+    <message>
+        <source>Number of entries in a result page</source>
+        <translation>Количество записей на страницу результатов</translation>
+    </message>
+    <message>
+        <source>If checked, results with the same content under different names will only be shown once.</source>
+        <translation>Показывать результаты с тем же содержанием под разными именами не более одного раза</translation>
+    </message>
+    <message>
+        <source>Hide duplicate results.</source>
+        <translation>Прятать дубликаты</translation>
+    </message>
+    <message>
+        <source>Highlight color for query terms</source>
+        <translation>Цвет выделения ключевых слов</translation>
+    </message>
+    <message>
+        <source>Result list font</source>
+        <translation>Шрифт списка результатов</translation>
+    </message>
+    <message>
+        <source>Opens a dialog to select the result list font</source>
+        <translation>Открывает диалог выбора шрифта списка результатов</translation>
+    </message>
+    <message>
+        <source>Helvetica-10</source>
+        <translation>Helvetica-10</translation>
+    </message>
+    <message>
+        <source>Resets the result list font to the system default</source>
+        <translation>Устанавливает шрифт списка результатов в обычный</translation>
+    </message>
+    <message>
+        <source>Reset</source>
+        <translation>Вернуть</translation>
+    </message>
+    <message>
+        <source>Defines the format for each result list paragraph. Use qt html format and printf-like replacements:&lt;br&gt;%A Abstract&lt;br&gt; %D Date&lt;br&gt; %I Icon image name&lt;br&gt; %K Keywords (if any)&lt;br&gt; %L Preview and Edit links&lt;br&gt; %M Mime type&lt;br&gt; %N Result number&lt;br&gt; %R Relevance percentage&lt;br&gt; %S Size information&lt;br&gt; %T Title&lt;br&gt; %U Url&lt;br&gt;</source>
+        <translation>Определяет формат каждого блока списка результатов. Используйте html-формат qt и замены в стиле printf:&lt;br&gt;%A аннотация&lt;br&gt; %D дата&lt;br&gt; %I название пиктограммы&lt;br&gt; %K ключевые слова (если есть)&lt;br&gt; %L ссылки предварительного просмотра и редактирования&lt;br&gt; %M тип MIME&lt;br&gt; %N количество результатов&lt;br&gt; %R релевантность&lt;br&gt; %S размер&lt;br&gt; %T заголовок&lt;br&gt; %U URL&lt;br&gt;</translation>
+    </message>
+    <message>
+        <source>Result paragraph&lt;br&gt;format string</source>
+        <translation>Строка форматирования&lt;br&gt;блока результатов</translation>
+    </message>
+    <message>
+        <source>Texts over this size will not be highlighted in preview (too slow).</source>
+        <translation>Тексты большего размера не будут подсвечиваться при предварительном просмотре (медленно).</translation>
+    </message>
+    <message>
+        <source>Maximum text size highlighted for preview (megabytes)</source>
+        <translation>Максимальный объём текста с выделением при просмотре (Мб)</translation>
+    </message>
+    <message>
+        <source>Use desktop preferences to choose document editor.</source>
+        <translation>Использовать десктопные настройки для выбора редактора документов.</translation>
+    </message>
+    <message>
+        <source>Choose editor applications</source>
+        <translation>Выбор редакторов</translation>
+    </message>
+    <message>
+        <source>Display category filter as toolbar instead of button panel (needs restart).</source>
+        <translation>Показывать фильтр категории документа в виде выпадающего списка, а не панели с кнопками (требуется перезапуск).</translation>
+    </message>
+    <message>
+        <source>Auto-start simple search on whitespace entry.</source>
+        <translation>Начинать простой поиск по вводу пробела.</translation>
+    </message>
+    <message>
+        <source>Start with advanced search dialog open.</source>
+        <translation>Открывать диалог сложного поиска при запуске.</translation>
+    </message>
+    <message>
+        <source>Start with sort dialog open.</source>
+        <translation type="obsolete">Открывать диалог сортировки при запуске.</translation>
+    </message>
+    <message>
+        <source>Remember sort activation state.</source>
+        <translation>Запомнить состояние сортировки.</translation>
+    </message>
+    <message>
+        <source>Prefer Html to plain text for preview.</source>
+        <translation>Предпочитать HTML тексту для предпросмотра</translation>
+    </message>
+    <message>
+        <source>Search parameters</source>
+        <translation>Параметры поиска</translation>
+    </message>
+    <message>
+        <source>Stemming language</source>
+        <translation>Язык словоформ</translation>
+    </message>
+    <message>
+        <source>A search for [rolling stones] (2 terms) will be changed to [rolling or stones or (rolling phrase 2 stones)]. 
+This should give higher precedence to the results where the search terms appear exactly as entered.</source>
+        <translation>Поиск [rolling stones] (два слова) будет изменён на [rolling или stones или (rolling phrase 2 stones)].
+Это может поднять результаты, для которых слова следуют именно в том порядке, как введены.</translation>
+    </message>
+    <message>
+        <source>Automatically add phrase to simple searches</source>
+        <translation>Автоматически добавлять фразу при простом поиске</translation>
+    </message>
+    <message>
+        <source>Do we try to build abstracts for result list entries by using the context of query terms ? 
+May be slow for big documents.</source>
+        <translation>Следует ли пытаться построить конспект из найденных документов, опираясь на контекст ключевых слов?
+Может быть медленным для больших документов.</translation>
+    </message>
+    <message>
+        <source>Dynamically build abstracts</source>
+        <translation>Динамическое выделение конспекта</translation>
+    </message>
+    <message>
+        <source>Do we synthetize an abstract even if the document seemed to have one?</source>
+        <translation>Создавать ли конспект, если документ уже имеет его?</translation>
+    </message>
+    <message>
+        <source>Replace abstracts from documents</source>
+        <translation>Замещать конспект, содержащийся в документах</translation>
+    </message>
+    <message>
+        <source>Synthetic abstract size (characters)</source>
+        <translation>Размер создаваемого конспекта (в символах)</translation>
+    </message>
+    <message>
+        <source>Synthetic abstract context words</source>
+        <translation>Контекстных слов</translation>
+    </message>
+    <message>
+        <source>The words in the list will be automatically turned to ext:xxx clauses in the query language entry.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Query language magic file name suffixes.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Enable</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>External Indexes</source>
+        <translation>Внешние индексы</translation>
+    </message>
+    <message>
+        <source>Toggle selected</source>
+        <translation>Переключить выделенные</translation>
+    </message>
+    <message>
+        <source>Activate All</source>
+        <translation>Включить все</translation>
+    </message>
+    <message>
+        <source>Deactivate All</source>
+        <translation>Выключить все</translation>
+    </message>
+    <message>
+        <source>Remove from list. This has no effect on the disk index.</source>
+        <translation>Удалить из списка. Индекс на диске без изменений.</translation>
+    </message>
+    <message>
+        <source>Remove selected</source>
+        <translation>Удалить выделенные</translation>
+    </message>
+    <message>
+        <source>Click to add another index directory to the list</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Add index</source>
+        <translation>Добавить индекс</translation>
+    </message>
+    <message>
+        <source>Apply changes</source>
+        <translation>Применить изменения</translation>
+    </message>
+    <message>
+        <source>&amp;OK</source>
+        <translation>&amp;OK</translation>
+    </message>
+    <message>
+        <source>Discard changes</source>
+        <translation>Отменить изменения</translation>
+    </message>
+    <message>
+        <source>&amp;Cancel</source>
+        <translation>&amp;Отмена</translation>
+    </message>
+</context>
 </TS>
