@@ -1,7 +1,4 @@
-#ifndef lint
-static char rcsid[] = "@(#$Id: preview_w.cpp,v 1.39 2008-10-07 16:19:15 dockes Exp $ (C) 2005 J.F.Dockes";
-#endif
-/*
+/* Copyright (C) 2005 J.F.Dockes
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
  *   the Free Software Foundation; either version 2 of the License, or
@@ -80,7 +77,13 @@ public:
 	if (m_inputhtml) {
 	    return snull;
 	} else {
-	    return string("<qt><head><title></title></head><body><pre>");
+	    if (prefs.previewPlainPre) {
+		m_eolbr = false;
+		return string("<qt><head><title></title></head><body><pre>");
+	    } else {
+		m_eolbr = true;
+		return string("<qt><head><title></title></head><body>");
+	    }
 	}
     }
     virtual string startMatch() 
@@ -515,7 +518,7 @@ void Preview::setCurTabProps(const Rcl::Doc &doc, int docnum)
     }
     LOGDEB(("Doc.url: [%s]\n", doc.url.c_str()));
     string url;
-    printableUrl(rclconfig->getDefCharset(), doc.url, url);
+    printableUrl(theconfig->getDefCharset(), doc.url, url);
     string tiptxt = url + string("\n");
     tiptxt += doc.mimetype + " " + string(datebuf) + "\n";
     if (meta_it != doc.meta.end() && !meta_it->second.empty())
@@ -535,6 +538,11 @@ bool Preview::makeDocCurrent(const Rcl::Doc& doc, int docnum, bool sametab)
 {
     LOGDEB(("Preview::makeDocCurrent: %s\n", doc.url.c_str()));
 
+    if (m_loading) {
+	LOGERR(("Already loading\n"));
+	return false;
+    }
+
     /* Check if we already have this page */
     for (int i = 0; i < pvTab->count(); i++) {
         QWidget *tw = pvTab->widget(i);
@@ -618,9 +626,10 @@ class LoadThread : public QThread {
 
       // QMessageBox::critical(0, "Recoll", Preview::tr("File does not exist"));
 	
-	FileInterner interner(idoc, rclconfig, tmpdir, 
+	FileInterner interner(idoc, theconfig, tmpdir, 
                               FileInterner::FIF_forPreview);
-
+	FIMissingStore mst;
+	interner.setMissingStore(&mst);
 	// We don't set the interner's target mtype to html because we
 	// do want the html filter to do its work: we won't use the
 	// text, but we need the conversion to utf-8
@@ -644,7 +653,7 @@ class LoadThread : public QThread {
 		}
 	    } else {
 		out.mimetype = interner.getMimetype();
-		interner.getMissingExternal(missing);
+		interner.getMissingExternal(&mst, missing);
 		*statusp = -1;
 	    }
 	} catch (CancelExcept) {
@@ -703,10 +712,6 @@ public:
 bool Preview::loadDocInCurrentTab(const Rcl::Doc &idoc, int docnum)
 {
     LOGDEB1(("PreviewTextEdit::loadDocInCurrentTab()\n"));
-    if (m_loading) {
-	LOGERR(("ALready loading\n"));
-	return false;
-    }
 
     LoadGuard guard(&m_loading);
     CancelCheck::instance().setCancel(false);
@@ -754,20 +759,20 @@ bool Preview::loadDocInCurrentTab(const Rcl::Doc &idoc, int docnum)
     if (CancelCheck::instance().cancelState())
 	return false;
     if (status != 0) {
-	QString explain;
-	if (!lthr.missing.empty()) {
-	    explain = QString::fromAscii("<br>") +
-		tr("Missing helper program: ") + 
-		QString::fromLocal8Bit(lthr.missing.c_str());
-	}
-	QMessageBox::warning(0, "Recoll",
-			     tr("Can't turn doc into internal "
-				"representation for ") +
-			     fdoc.mimetype.c_str() + explain);
+        QString explain;
+        if (!lthr.missing.empty()) {
+            explain = QString::fromAscii("<br>") +
+                tr("Missing helper program: ") +
+                QString::fromLocal8Bit(lthr.missing.c_str());
+        }
+        QMessageBox::warning(0, "Recoll",
+                             tr("Can't turn doc into internal "
+                                "representation for ") +
+                             fdoc.mimetype.c_str() + explain);
 	return false;
     }
     // Reset config just in case.
-    rclconfig->setKeyDir("");
+    theconfig->setKeyDir("");
 
     // Create preview text: highlight search terms
     // We don't do the highlighting for very big texts: too long. We
