@@ -97,9 +97,10 @@ public slots:
     virtual void on_actionSortByDateAsc_toggled(bool on);
     virtual void on_actionSortByDateDesc_toggled(bool on);
     virtual void on_actionShowResultsAsTable_toggled(bool on);
-    virtual void onResTableSortBy(DocSeqSortSpec);
+    virtual void onSortDataChanged(DocSeqSortSpec);
     virtual void resultCount(int);
     virtual void showQueryDetails();
+    virtual void onResultsChanged();
 
 signals:
     void docSourceChanged(RefCntr<DocSequence>);
@@ -132,7 +133,8 @@ private:
     bool              m_sortspecnochange;
     DocSeqSortSpec    m_sortspec;
     RefCntr<DocSequence> m_source;
-    
+    int               m_periodicToggle;
+
     virtual void init();
     virtual void previewPrevOrNextInTab(Preview *, int sid, int docnum, 
 					bool next);
