@@ -1,4 +1,4 @@
-/*
+/* Copyright (C) 2004 J.F.Dockes
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
  *   the Free Software Foundation; either version 2 of the License, or
@@ -16,22 +16,27 @@
  */
 #ifndef _RECOLL_H_INCLUDED_
 #define _RECOLL_H_INCLUDED_
-/* @(#$Id: recoll.h,v 1.19 2008-11-24 15:23:12 dockes Exp $  (C) 2004 J.F.Dockes */
 #include <string>
 
 #include "rclconfig.h"
 #include "rcldb.h"
 #include "idxthread.h"
+#include "ptmutex.h"
 
 // Misc declarations in need of sharing between the UI files
 
 // Open the database if needed. We now force a close/open by default
-extern bool maybeOpenDb(std::string &reason, bool force = true);
+extern bool maybeOpenDb(std::string &reason, bool force = true, 
+			bool *maindberror = 0);
 
 /** Retrieve configured stemming languages */
 bool getStemLangs(list<string>& langs);
 
-extern RclConfig *rclconfig;
+extern RclConfig *theconfig;
+extern RclConfig *thestableconfig;
+extern PTMutexInit thestableconfiglock;
+extern void snapshotConfig();
+
 extern Rcl::Db *rcldb;
 extern int recollNeedsExit;
 extern int startIndexingAfterConfig; // 1st startup
