@@ -1,7 +1,4 @@
-#ifndef lint
-static char rcsid[] = "@(#$Id: viewaction_w.cpp,v 1.5 2007-09-08 17:21:49 dockes Exp $ (C) 2006 J.F.Dockes";
-#endif
-/*
+/* Copyright (C) 2006 J.F.Dockes 
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
  *   the Free Software Foundation; either version 2 of the License, or
@@ -54,7 +51,7 @@ void ViewAction::fillLists()
     actionsLV->clear();
     actionsLV->verticalHeader()->setDefaultSectionSize(20); 
     vector<pair<string, string> > defs;
-    rclconfig->getMimeViewerDefs(defs);
+    theconfig->getMimeViewerDefs(defs);
     actionsLV->setRowCount(defs.size());
     int row = 0;
     for (vector<pair<string, string> >::const_iterator it = defs.begin();
@@ -131,7 +128,7 @@ void ViewAction::editActions()
     string sact = (const char *)newaction.toLocal8Bit();
     for (list<string>::const_iterator it = mtypes.begin(); 
 	 it != mtypes.end(); it++) {
-	rclconfig->setMimeViewerDef(*it, sact);
+	theconfig->setMimeViewerDef(*it, sact);
     }
     fillLists();
 }
