@@ -1,4 +1,4 @@
-/*
+/* Copyright (C) 2004 J.F.Dockes
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
  *   the Free Software Foundation; either version 2 of the License, or
@@ -16,7 +16,6 @@
  */
 #ifndef _DOCSEQ_H_INCLUDED_
 #define _DOCSEQ_H_INCLUDED_
-/* @(#$Id: docseq.h,v 1.17 2008-09-29 11:33:55 dockes Exp $  (C) 2004 J.F.Dockes */
 #include <string>
 #include <list>
 #include <vector>
@@ -98,7 +97,7 @@ class DocSequence {
 	return doc.meta[Rcl::Doc::keyabs];
     }
 
-    virtual bool getEnclosing(Rcl::Doc&, Rcl::Doc&) {return false;}
+    virtual bool getEnclosing(Rcl::Doc&, Rcl::Doc&) = 0;
 
     /** Get estimated total count in results */
     virtual int getResCnt() = 0;
@@ -173,6 +172,12 @@ public:
 	    return false;
 	return m_seq->getTerms(terms, groups, gslks);
     }
+    virtual bool getEnclosing(Rcl::Doc& doc, Rcl::Doc& pdoc) 
+    {
+	if (m_seq.isNull())
+	    return false;
+	return m_seq->getEnclosing(doc, pdoc);
+    }
     virtual void getUTerms(vector<string>& terms)
     {
 	if (m_seq.isNull())
