@@ -1,6 +1,19 @@
-#ifndef lint
-static char rcsid[] = "@(#$Id: reslistpager.cpp,v 1.7 2008-12-16 14:20:10 dockes Exp $ (C) 2007 J.F.Dockes";
-#endif
+/* Copyright (C) 2007 J.F.Dockes
+ *   This program is free software; you can redistribute it and/or modify
+ *   it under the terms of the GNU General Public License as published by
+ *   the Free Software Foundation; either version 2 of the License, or
+ *   (at your option) any later version.
+ *
+ *   This program is distributed in the hope that it will be useful,
+ *   but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *   GNU General Public License for more details.
+ *
+ *   You should have received a copy of the GNU General Public License
+ *   along with this program; if not, write to the
+ *   Free Software Foundation, Inc.,
+ *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ */
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -359,7 +372,7 @@ string ResListPager::detailsLink()
 
 const string &ResListPager::parFormat()
 {
-    const static string format("<img src=\"%I\" align=\"left\">"
+    static const string format("<img src=\"%I\" align=\"left\">"
 			       "%R %S %L &nbsp;&nbsp;<b>%T</b><br>"
 			       "%M&nbsp;%D&nbsp;&nbsp;&nbsp;<i>%U</i><br>"
 			       "%A %K");
