@@ -83,6 +83,40 @@ string version_string(){
 // found in document)
 static const string rclSyntAbs("?!#@");
 
+// Only ONE field name inside the index data record differs from the
+// Rcl::Doc ones: caption<->title, for a remnant of compatibility with
+// omega
+static const string keycap("caption");
+
+// Default table for field->prefix translation.  We prefer the data
+// from rclconfig if available. Note that this is logically const
+// after initialization.  Can't use a static object to init this as
+// the static std::string objects may not be ready
+static map<string, string> fldToPrefs;
+static void initFldToPrefs() 
+{
+    fldToPrefs[Doc::keyabs] = string();
+    fldToPrefs["ext"] = "XE";
+    fldToPrefs[Doc::keyfn] = "XSFN";
+
+    fldToPrefs[keycap] = "S";
+    fldToPrefs[Doc::keytt] = "S";
+    fldToPrefs["subject"] = "S";
+
+    fldToPrefs[Doc::keyau] = "A";
+    fldToPrefs["creator"] = "A";
+    fldToPrefs["from"] = "A";
+
+    fldToPrefs[Doc::keykw] = "K";
+    fldToPrefs["keyword"] = "K";
+    fldToPrefs["tag"] = "K";
+    fldToPrefs["tags"] = "K";
+
+    fldToPrefs["xapyear"] = "Y";
+    fldToPrefs["xapyearmon"] = "M";
+    fldToPrefs["xapdate"] = "D";
+}
+
 // Compute the unique term used to link documents to their origin. 
 // "Q" + external udi
 static inline string make_uniterm(const string& udi)
@@ -131,11 +165,6 @@ bool Db::Native::subDocs(const string &udi, vector<Xapian::docid>& docids)
     }
 }
 
-// Only ONE field name inside the index data record differs from the
-// Rcl::Doc ones: caption<->title, for a remnant of compatibility with
-// omega
-static const string keycap("caption");
-
 // Turn data record from db into document fields
 bool Db::Native::dbDataToRclDoc(Xapian::docid docid, std::string &data, 
 				Doc &doc)
@@ -510,6 +539,9 @@ Db::Db(RclConfig *cfp)
       m_curtxtsz(0), m_flushtxtsz(0), m_occtxtsz(0), m_occFirstCheck(1),
       m_maxFsOccupPc(0), m_mode(Db::DbRO)
 {
+    if (!fldToPrefs.size())
+	initFldToPrefs();
+
     m_ndb = new Native(this);
     if (m_config) {
 	m_config->getConfParam("maxfsoccuppc", &m_maxFsOccupPc);
@@ -759,39 +791,6 @@ bool Db::isopen()
 // reason (old config not updated ?). We use it only if the config
 // translation fails. Also we add in there fields which should be
 // indexed with no prefix (ie: abstract)
-
-// Default table. We prefer the data from rclconfig if available. Note
-// that it is logically const after initialization. This would be
-// simpler with c0xx initializer lists.
-static map<string, string> fldToPrefs;
-class InitFldToPrefs {
-public:
-    InitFldToPrefs() 
-    {
-	fldToPrefs[Doc::keyabs] = string();
-	fldToPrefs["ext"] = "XE";
-	fldToPrefs[Doc::keyfn] = "XSFN";
-
-	fldToPrefs[keycap] = "S";
-	fldToPrefs[Doc::keytt] = "S";
-	fldToPrefs["subject"] = "S";
-
-	fldToPrefs[Doc::keyau] = "A";
-	fldToPrefs["creator"] = "A";
-	fldToPrefs["from"] = "A";
-
-	fldToPrefs[Doc::keykw] = "K";
-	fldToPrefs["keyword"] = "K";
-	fldToPrefs["tag"] = "K";
-	fldToPrefs["tags"] = "K";
-
-        fldToPrefs["xapyear"] = "Y";
-        fldToPrefs["xapyearmon"] = "M";
-        fldToPrefs["xapdate"] = "D";
-    }
-};
-static InitFldToPrefs IFTP;
-
 bool Db::fieldToPrefix(const string& fld, string &pfx)
 {
     if (m_config && m_config->getFieldPrefix(fld, pfx))
