@@ -1,4 +1,4 @@
-/*
+/* Copyright (C) 2004 J.F.Dockes
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
  *   the Free Software Foundation; either version 2 of the License, or
@@ -16,7 +16,6 @@
  */
 #ifndef _DB_H_INCLUDED_
 #define _DB_H_INCLUDED_
-/* @(#$Id: rcldb.h,v 1.65 2008-12-19 09:55:36 dockes Exp $  (C) 2004 J.F.Dockes */
 
 #include <string>
 #include <list>
@@ -96,7 +95,8 @@ class Db {
     ~Db();
 
     enum OpenMode {DbRO, DbUpd, DbTrunc};
-    bool open(OpenMode mode);
+    enum OpenError {DbOpenNoError, DbOpenMainDb, DbOpenExtraDb};
+    bool open(OpenMode mode, OpenError *error = 0);
     bool close();
     bool isopen();
 
@@ -233,6 +233,8 @@ private:
     long long    m_flushtxtsz;
     // Text bytes at last fsoccup check
     long long    m_occtxtsz;
+    // First fs occup check ?
+    int         m_occFirstCheck;
     // Maximum file system occupation percentage
     int          m_maxFsOccupPc;
 
