@@ -1,6 +1,19 @@
-#ifndef lint
-static char rcsid[] = "@(#$Id: stemdb.cpp,v 1.12 2008-07-30 13:16:13 dockes Exp $ (C) 2005 J.F.Dockes";
-#endif
+/* Copyright (C) 2005 J.F.Dockes 
+ *   This program is free software; you can redistribute it and/or modify
+ *   it under the terms of the GNU General Public License as published by
+ *   the Free Software Foundation; either version 2 of the License, or
+ *   (at your option) any later version.
+ *
+ *   This program is distributed in the hope that it will be useful,
+ *   but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *   GNU General Public License for more details.
+ *
+ *   You should have received a copy of the GNU General Public License
+ *   along with this program; if not, write to the
+ *   Free Software Foundation, Inc.,
+ *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ */
 
 /**
  * Management of the auxiliary databases listing stems and their expansion 
@@ -25,7 +38,7 @@ namespace Rcl {
 namespace StemDb {
 
 
-const static string stemdirstem = "stem_";
+static const string stemdirstem = "stem_";
 
 /// Compute name of stem db for given base database and language
 static string stemdbname(const string& dbdir, const string& lang)
